@@ -1,6 +1,6 @@
 /**
  * @file align.h
- * prototypes for align.c
+ * prototypes for align.cpp
  *
  * @author  Ben Gardner
  * @license GPL v2+
@@ -11,6 +11,6 @@
 #include "uncrustify_types.h"
 
 
-void align_all(void);
+void align_all();
 
 #endif /* ALIGN_H_INCLUDED */
