@@ -10,10 +10,10 @@
 #include "align_asm_colon.h"
 
 #include "align_stack.h"
-#include "chunk_list.h"
+#include "chunk.h"
 
 
-void align_asm_colon(void)
+void align_asm_colon()
 {
    LOG_FUNC_ENTRY();
 
@@ -22,30 +22,30 @@ void align_asm_colon(void)
 
    cas.Start(4);
 
-   chunk_t *pc = chunk_get_head();
+   Chunk *pc = Chunk::GetHead();
 
-   while (pc != nullptr)
+   while (pc->IsNotNullChunk())
    {
-      if (chunk_is_not_token(pc, CT_ASM_COLON))
+      if (pc->IsNot(CT_ASM_COLON))
       {
-         pc = chunk_get_next(pc);
+         pc = pc->GetNext();
          continue;
       }
       cas.Reset();
 
-      pc = chunk_get_next_ncnl(pc, scope_e::PREPROC);
-      size_t level = pc ? pc->level : 0;
+      pc = pc->GetNextNcNnl(E_Scope::PREPROC);
+      size_t level = pc->IsNotNullChunk() ? pc->GetLevel() : 0;
       did_nl = true;
 
-      while (  pc != nullptr
-            && pc->level >= level)
+      while (  pc->IsNotNullChunk()
+            && pc->GetLevel() >= level)
       {
-         if (chunk_is_newline(pc))
+         if (pc->IsNewline())
          {
-            cas.NewLines(pc->nl_count);
+            cas.NewLines(pc->GetNlCount());
             did_nl = true;
          }
-         else if (chunk_is_token(pc, CT_ASM_COLON))
+         else if (pc->Is(CT_ASM_COLON))
          {
             cas.Flush();
             did_nl = true;
@@ -55,7 +55,7 @@ void align_asm_colon(void)
             did_nl = false;
             cas.Add(pc);
          }
-         pc = chunk_get_next_nc(pc, scope_e::PREPROC);
+         pc = pc->GetNextNc(E_Scope::PREPROC);
       }
       cas.End();
    }
