@@ -6,6 +6,7 @@
  * @author  Ben Gardner
  * @license GPL v2+
  */
+
 #ifndef ALIGN_ASM_COLON_H_INCLUDED
 #define ALIGN_ASM_COLON_H_INCLUDED
 
@@ -19,6 +20,6 @@
  *    : "z"(h)
  *    );
  */
-void align_asm_colon(void);
+void align_asm_colon();
 
 #endif /* ALIGN_ASM_COLON_H_INCLUDED */
