@@ -9,6 +9,6 @@
 #define ALIGN_EIGEN_COMMA_INIT_H_INCLUDED
 
 //! Align comma-separated expressions following left shift operator '<<'
-void align_eigen_comma_init(void);
+void align_eigen_comma_init();
 
 #endif /* ALIGN_EIGEN_COMMA_INIT_H_INCLUDED */
