@@ -10,10 +10,10 @@
 #ifndef ALIGN_FUNC_PARAMS_H_INCLUDED
 #define ALIGN_FUNC_PARAMS_H_INCLUDED
 
-#include "chunk_list.h"
+#include "chunk.h"
 
-void align_func_params(void);
+void align_func_params();
 
-chunk_t *align_func_param(chunk_t *start);
+Chunk *align_func_param(Chunk *start);
 
 #endif /* ALIGN_FUNC_PARAMS_H_INCLUDED */
