@@ -11,6 +11,6 @@
 #define ALIGN_LEFT_SHIFT_H_INCLUDED
 
 //! Align left shift operators '<<' (CT_SHIFT)
-void align_left_shift(void);
+void align_left_shift();
 
 #endif /* ALIGN_LEFT_SHIFT_H_INCLUDED */
