@@ -12,7 +12,7 @@
 
 #include "uncrustify_types.h"
 
-#include "chunk_list.h"
+#include "chunk.h"
 
 /**
  * For a series of lines ending in backslash-newline, align them.
@@ -20,14 +20,14 @@
  *
  * @param start   Start point
  *
- * @return pointer the last item looked at (nullptr/newline/comment)
+ * @return pointer the last item looked at (null chunk/newline/comment)
  */
-chunk_t *align_nl_cont(chunk_t *start);
+Chunk *align_nl_cont(Chunk *start);
 
 /**
  * Aligns all backslash-newline combos in the file.
  * This should be done LAST.
  */
-void align_backslash_newline(void);
+void align_backslash_newline();
 
 #endif /* ALIGN_NL_COUNT_H_INCLUDED */
