@@ -11,6 +11,6 @@
 #define ALIGN_OC_MSG_COLONS_H_INCLUDED
 
 //! Aligns OC messages
-void align_oc_msg_colons(void);
+void align_oc_msg_colons();
 
 #endif /* ALIGN_OC_MSG_COLONS_H_INCLUDED */
