@@ -21,13 +21,13 @@ void align_oc_msg_spec(size_t span)
 
    as.Start(span, 0);
 
-   for (chunk_t *pc = chunk_get_head(); pc != nullptr; pc = chunk_get_next(pc))
+   for (Chunk *pc = Chunk::GetHead(); pc->IsNotNullChunk(); pc = pc->GetNext())
    {
-      if (chunk_is_newline(pc))
+      if (pc->IsNewline())
       {
-         as.NewLines(pc->nl_count);
+         as.NewLines(pc->GetNlCount());
       }
-      else if (chunk_is_token(pc, CT_OC_MSG_SPEC))
+      else if (pc->Is(CT_OC_MSG_SPEC))
       {
          as.Add(pc);
       }
