@@ -13,7 +13,8 @@
 #include "align_tab_column.h"
 #include "indent.h"
 #include "log_rules.h"
-#include "uncrustify.h"
+
+constexpr static auto LCURRENT = LALTC;
 
 using namespace uncrustify;
 
@@ -30,31 +31,32 @@ void align_stack(ChunkStack &cs, size_t col, bool align_single, log_sev_t sev)
    }
 
    if (  (cs.Len() > 1)
-      || (align_single && (cs.Len() == 1)))
+      || (  align_single
+         && (cs.Len() == 1)))
    {
       LOG_FMT(sev, "%s(%d): max_col=%zu\n", __func__, __LINE__, col);
-      chunk_t *pc;
+      Chunk *pc;
 
-      while ((pc = cs.Pop_Back()) != nullptr)
+      while ((pc = cs.Pop_Back())->IsNotNullChunk())
       {
          align_to_column(pc, col);
-         chunk_flags_set(pc, PCF_WAS_ALIGNED);
+         pc->SetFlagBits(PCF_WAS_ALIGNED);
 
          LOG_FMT(sev, "%s(%d): indented [%s] on line %zu to %zu\n",
-                 __func__, __LINE__, pc->text(), pc->orig_line, pc->column);
+                 __func__, __LINE__, pc->Text(), pc->GetOrigLine(), pc->GetColumn());
       }
    }
    cs.Reset();
 } // align_stack
 
 
-chunk_t *align_trailing_comments(chunk_t *start)
+Chunk *align_trailing_comments(Chunk *start)
 {
    LOG_FUNC_ENTRY();
    size_t       min_col  = 0;
    size_t       min_orig = 0;
-   chunk_t      *pc      = start;
-   const size_t lvl      = start->brace_level;
+   Chunk        *pc      = start;
+   const size_t lvl      = start->GetBraceLevel();
    size_t       nl_count = 0;
    ChunkStack   cs;
    size_t       col;
@@ -68,19 +70,21 @@ chunk_t *align_trailing_comments(chunk_t *start)
    comment_align_e cmt_type_start = get_comment_align_type(pc);
 
    LOG_FMT(LALADD, "%s(%d): start on line=%zu\n",
-           __func__, __LINE__, pc->orig_line);
+           __func__, __LINE__, pc->GetOrigLine());
 
    // Find the max column
    log_rule_B("align_right_cmt_span");
 
-   while (  pc != nullptr
+   while (  pc->IsNotNullChunk()
          && (nl_count < options::align_right_cmt_span()))
    {
-      if (pc->flags.test(PCF_RIGHT_COMMENT) && pc->column > 1)
+      if (  pc->TestFlags(PCF_RIGHT_COMMENT)
+         && pc->GetColumn() > 1)
       {
-         if (same_level && pc->brace_level != lvl)
+         if (  same_level
+            && pc->GetBraceLevel() != lvl)
          {
-            pc = chunk_get_prev(pc);
+            pc = pc->GetPrev();
             break;
          }
          cmt_type_cur = get_comment_align_type(pc);
@@ -88,29 +92,31 @@ chunk_t *align_trailing_comments(chunk_t *start)
          if (cmt_type_cur == cmt_type_start)
          {
             LOG_FMT(LALADD, "%s(%d): line=%zu min_col=%zu pc->col=%zu pc->len=%zu %s\n",
-                    __func__, __LINE__, pc->orig_line, min_col, pc->column, pc->len(),
-                    get_token_name(pc->type));
+                    __func__, __LINE__, pc->GetOrigLine(), min_col, pc->GetColumn(), pc->Len(),
+                    get_token_name(pc->GetType()));
 
-            if (min_orig == 0 || min_orig > pc->column)
+            if (  min_orig == 0
+               || min_orig > pc->GetColumn())
             {
-               min_orig = pc->column;
+               min_orig = pc->GetColumn();
             }
             align_add(cs, pc, min_col); // (intended_col < col));
             nl_count = 0;
          }
       }
 
-      if (chunk_is_newline(pc))
+      if (pc->IsNewline())
       {
-         nl_count += pc->nl_count;
+         nl_count += pc->GetNlCount();
       }
-      pc = chunk_get_next(pc);
+      pc = pc->GetNext();
    }
    // Start with the minimum original column
    col = min_orig;
 
    // fall back to the intended column
-   if (intended_col > 0 && col > intended_col)
+   if (  intended_col > 0
+      && col > intended_col)
    {
       col = intended_col;
    }
@@ -129,35 +135,37 @@ chunk_t *align_trailing_comments(chunk_t *start)
    LOG_FMT(LALADD, "%s(%d):  -- min_orig=%zu intended_col=%zu min_allowed=%zu ==> col=%zu\n",
            __func__, __LINE__, min_orig, intended_col, min_col, col);
 
-   if (cpd.frag_cols > 0 && cpd.frag_cols <= col)
+   if (  cpd.frag_cols > 0
+      && cpd.frag_cols <= col)
    {
       col -= cpd.frag_cols;
    }
    align_stack(cs, col, (intended_col != 0), LALTC);
 
-   return(chunk_get_next(pc));
+   return(pc->GetNext());
 } // align_trailing_comments
 
 
-comment_align_e get_comment_align_type(chunk_t *cmt)
+comment_align_e get_comment_align_type(Chunk *cmt)
 {
-   chunk_t         *prev;
+   Chunk           *prev;
    comment_align_e cmt_type = comment_align_e::REGULAR;
 
    log_rule_B("align_right_cmt_mix");
 
    if (  !options::align_right_cmt_mix()
-      && ((prev = chunk_get_prev(cmt)) != nullptr))
+      && cmt->IsNotNullChunk()
+      && ((prev = cmt->GetPrev())->IsNotNullChunk()))
    {
-      if (  chunk_is_token(prev, CT_PP_ENDIF)
-         || chunk_is_token(prev, CT_PP_ELSE)
-         || chunk_is_token(prev, CT_ELSE)
-         || chunk_is_token(prev, CT_BRACE_CLOSE))
+      if (  prev->Is(CT_PP_ENDIF)
+         || prev->Is(CT_PP_ELSE)
+         || prev->Is(CT_ELSE)
+         || prev->Is(CT_BRACE_CLOSE))
       {
          // TODO: make the magic 3 configurable
-         if ((cmt->column - (prev->column + prev->len())) < 3)
+         if ((cmt->GetColumn() - (prev->GetColumn() + prev->Len())) < 3)
          {
-            cmt_type = (chunk_is_token(prev, CT_PP_ENDIF)) ? comment_align_e::ENDIF : comment_align_e::BRACE;
+            cmt_type = (prev->Is(CT_PP_ENDIF)) ? comment_align_e::ENDIF : comment_align_e::BRACE;
          }
       }
    }
@@ -165,65 +173,63 @@ comment_align_e get_comment_align_type(chunk_t *cmt)
 } // get_comment_align_type
 
 
-void align_right_comments(void)
+void align_right_comments()
 {
    LOG_FUNC_ENTRY();
 
-   for (chunk_t *pc = chunk_get_head(); pc != nullptr; pc = chunk_get_next(pc))
+   for (Chunk *pc = Chunk::GetHead(); pc->IsNotNullChunk(); pc = pc->GetNext())
    {
-      if (  chunk_is_token(pc, CT_COMMENT)
-         || chunk_is_token(pc, CT_COMMENT_CPP)
-         || chunk_is_token(pc, CT_COMMENT_MULTI))
+      if (  pc->Is(CT_COMMENT)
+         || pc->Is(CT_COMMENT_CPP)
+         || pc->Is(CT_COMMENT_MULTI))
       {
-         if (get_chunk_parent_type(pc) == CT_COMMENT_END)
+         if (pc->GetParentType() == CT_COMMENT_END)
          {
-            chunk_t *prev = chunk_get_prev(pc);
-
             log_rule_B("align_right_cmt_gap");
 
-            if (pc->orig_col < prev->orig_col_end + options::align_right_cmt_gap())
+            if (pc->GetOrigPrevSp() < options::align_right_cmt_gap())
             {
-               LOG_FMT(LALTC, "NOT changing END comment on line %zu (%zu <= %zu + %u)\n",
-                       pc->orig_line, pc->orig_col, prev->orig_col_end,
+               LOG_FMT(LALTC, "NOT changing END comment on line %zu (%zu < %u)\n",
+                       pc->GetOrigLine(), pc->GetOrigPrevSp(),
                        options::align_right_cmt_gap());
             }
             else
             {
                LOG_FMT(LALTC, "Changing END comment on line %zu into a RIGHT-comment\n",
-                       pc->orig_line);
-               chunk_flags_set(pc, PCF_RIGHT_COMMENT);
+                       pc->GetOrigLine());
+               pc->SetFlagBits(PCF_RIGHT_COMMENT);
             }
          }
 
          // Change certain WHOLE comments into RIGHT-alignable comments
-         if (get_chunk_parent_type(pc) == CT_COMMENT_WHOLE)
+         if (pc->GetParentType() == CT_COMMENT_WHOLE)
          {
             log_rule_B("input_tab_size");
-            size_t max_col = pc->column_indent + options::input_tab_size();
+            size_t max_col = pc->GetColumnIndent() + options::input_tab_size();
 
             // If the comment is further right than the brace level...
-            if (pc->column >= max_col)
+            if (pc->GetColumn() >= max_col)
             {
                LOG_FMT(LALTC, "Changing WHOLE comment on line %zu into a RIGHT-comment (col=%zu col_ind=%zu max_col=%zu)\n",
-                       pc->orig_line, pc->column, pc->column_indent, max_col);
+                       pc->GetOrigLine(), pc->GetColumn(), pc->GetColumnIndent(), max_col);
 
-               chunk_flags_set(pc, PCF_RIGHT_COMMENT);
+               pc->SetFlagBits(PCF_RIGHT_COMMENT);
             }
          }
       }
    }
 
-   chunk_t *pc = chunk_get_head();
+   Chunk *pc = Chunk::GetHead();
 
-   while (pc != nullptr)
+   while (pc->IsNotNullChunk())
    {
-      if (pc->flags.test(PCF_RIGHT_COMMENT))
+      if (pc->TestFlags(PCF_RIGHT_COMMENT))
       {
          pc = align_trailing_comments(pc);
       }
       else
       {
-         pc = chunk_get_next(pc);
+         pc = pc->GetNext();
       }
    }
 } // align_right_comments
