@@ -10,7 +10,7 @@
 #ifndef ALIGN_TRAILING_COMMENTS_H_INCLUDED
 #define ALIGN_TRAILING_COMMENTS_H_INCLUDED
 
-#include "chunk_list.h"
+#include "chunk.h"
 #include "ChunkStack.h"
 
 enum class comment_align_e : unsigned int
@@ -35,12 +35,12 @@ enum class comment_align_e : unsigned int
  * @param start   Start point
  * @return        pointer the last item looked at
  */
-chunk_t *align_trailing_comments(chunk_t *start);
+Chunk *align_trailing_comments(Chunk *start);
 
-comment_align_e get_comment_align_type(chunk_t *cmt);
+comment_align_e get_comment_align_type(Chunk *cmt);
 
 void align_stack(ChunkStack &cs, size_t col, bool align_single, log_sev_t sev);
 
-void align_right_comments(void);
+void align_right_comments();
 
 #endif /* ALIGN_TRAILING_COMMENTS_H_INCLUDED */
