@@ -15,7 +15,7 @@
  * CT_Q_COLON, CT_LABEL_COLON, or CT_CASE_COLON.
  * It also changes the CT_WORD before CT_LABEL_COLON into CT_LABEL.
  */
-void combine_labels(void);
+void combine_labels();
 
 
 #endif /* COMBINE_LABELS_H_INCLUDED */
