@@ -29,14 +29,14 @@ bool unc_getenv(const char *name, std::string &str)
    }
    buf = (char *)malloc(len);
 
-   if (buf)
+   if (buf != nullptr)
    {
       len = GetEnvironmentVariableA(name, buf, len);
    }
    buf[len] = 0;
 
    str = buf;
-   //printf("%s: name=%s len=%d value=%s\n", __func__, name, (int)len, str.c_str());
+   //printf("%s: name=%s len=%zu value=%s\n", __func__, name, len, str.c_str());
    free(buf);
 
    return(true);
@@ -56,7 +56,8 @@ bool unc_homedir(std::string &home)
    }
    std::string hd, hp;
 
-   if (unc_getenv("HOMEDRIVE", hd) && unc_getenv("HOMEPATH", hp))
+   if (  unc_getenv("HOMEDRIVE", hd)
+      && unc_getenv("HOMEPATH", hp))
    {
       home = hd + hp;
       return(true);
