@@ -9,8 +9,8 @@
 
 /**
  * Scans through the whole list and does stuff.
- * works on the last comma withing enum
+ * works on the last comma within enum
  */
-void enum_cleanup(void);
+void enum_cleanup();
 
 #endif /* ENUM_CLEANUP_H_INCLUDED */
