@@ -10,16 +10,11 @@
  * @license GPL v2+
  */
 
-#include "compat.h"
-#include "log_levels.h"
 #include "logger.h"
-#include "unc_ctype.h"
-#include "uncrustify_types.h"
 
-#include <cstdio>
-#include <deque>
-#include <stdarg.h>
-#include <vector>
+#include "compat.h"
+
+#include <cstdarg>                   // to get va_start, va_end
 
 
 struct log_fcn_info
@@ -57,6 +52,8 @@ struct log_buf
    log_mask_t        mask;
    bool              show_hdr;  //! flag determine if a header gets added to log message
 };
+
+
 static struct log_buf g_log;
 
 
@@ -74,7 +71,7 @@ static size_t log_start(log_sev_t sev);
  * Cleans up after a log statement by detecting whether the log is done,
  * (it ends in a newline) and possibly flushing the log.
  */
-static void log_end(void);
+static void log_end();
 
 
 /**
@@ -129,7 +126,8 @@ void log_flush(bool force_nl)
 {
    if (g_log.buf_len > 0)
    {
-      if (force_nl && g_log.bufX[g_log.buf_len - 1] != '\n')
+      if (  force_nl
+         && g_log.bufX[g_log.buf_len - 1] != '\n')
       {
          g_log.bufX[g_log.buf_len++] = '\n';
          g_log.bufX[g_log.buf_len]   = 0;
@@ -158,7 +156,8 @@ static size_t log_start(log_sev_t sev)
    }
 
    // If not in a log, the buffer is empty. Add the header, if enabled.
-   if (!g_log.in_log && g_log.show_hdr)
+   if (  !g_log.in_log
+      && g_log.show_hdr)
    {
       g_log.buf_len = static_cast<size_t>(snprintf(&g_log.bufX[0], g_log.bufX.size(), "<%d>", sev));
    }
@@ -168,7 +167,7 @@ static size_t log_start(log_sev_t sev)
 }
 
 
-static void log_end(void)
+static void log_end()
 {
    g_log.in_log = (g_log.bufX[g_log.buf_len - 1] != '\n');
 
@@ -182,7 +181,8 @@ static void log_end(void)
 
 void log_fmt(log_sev_t sev, const char *fmt, ...)
 {
-   if (fmt == nullptr || !log_sev_on(sev))
+   if (  fmt == nullptr
+      || !log_sev_on(sev))
    {
       return;
    }
@@ -194,14 +194,14 @@ void log_fmt(log_sev_t sev, const char *fmt, ...)
       return;
    }
    // the value of buffer_length is experimental
-   const int buffer_length = 4100;
+   const int buffer_length = 40000;
    char      buf[buffer_length];
 
    // it MUST be a 'unsigned int' variable to be runable under windows
 
    if (length >= buffer_length)
    {
-      fprintf(stderr, "FATAL(1): The variable 'buf' is not big enought:\n");
+      fprintf(stderr, "FATAL(1): The variable 'buf' is not big enough:\n");
       fprintf(stderr, "   it should be bigger as %u\n", length);
       fprintf(stderr, "Please make a report.\n");
       fprintf(stderr, "For the buffer: %s\n", fmt);
@@ -243,7 +243,7 @@ void log_fmt(log_sev_t sev, const char *fmt, ...)
 
             if (X >= buffer_length)
             {
-               fprintf(stderr, "FATAL(2): The variable 'buf' is not big enought:\n");
+               fprintf(stderr, "FATAL(2): The variable 'buf' is not big enough:\n");
                fprintf(stderr, "   it should be bigger as %zu\n", X);
                fprintf(stderr, "Please make a report.\n");
                fprintf(stderr, "For the buffer: %s\n", fmt);
@@ -279,7 +279,7 @@ void log_func_stack(log_sev_t sev, const char *prefix, const char *suffix, size_
 {
    UNUSED(skip_cnt);
 
-   if (prefix)
+   if (prefix != nullptr)
    {
       LOG_FMT(sev, "%s", prefix);
    }
@@ -304,8 +304,33 @@ void log_func_stack(log_sev_t sev, const char *prefix, const char *suffix, size_
    LOG_FMT(sev, "-DEBUG NOT SET-");
 #endif
 
-   if (suffix)
+   if (suffix != nullptr)
    {
       LOG_FMT(sev, "%s", suffix);
    }
 }
+
+
+const char *get_unqualified_func_name(const char *func)
+{
+   /**
+    * we look for the last ':' character;
+    */
+   for (auto i = strlen(func); i > 0; --i)
+   {
+      if (func[i - 1] == ':')
+      {
+         /**
+          * function name is qualified, so return the
+          * unqualified portion
+          */
+         return(func + i);
+      }
+   }
+
+   /**
+    * input function name is unqualified
+    */
+
+   return(func);
+}
