@@ -20,13 +20,14 @@
 /*
  * the test suite Coveralls: https://coveralls.io
  * will complains because these functions are only
- * used at developement time.
- * Don't worry about unsed lines for the functions:
+ * used at development time.
+ * Don't worry about unused lines for the functions:
  *   logmask_to_str
  */
 char *logmask_to_str(const log_mask_t &mask, char *buf, int size)
 {
-   if (buf == nullptr || size <= 0)
+   if (  buf == nullptr
+      || size <= 0)
    {
       return(buf);
    }
@@ -61,7 +62,8 @@ char *logmask_to_str(const log_mask_t &mask, char *buf, int size)
    }
 
    // handle a range that ends on the last bit
-   if (is_range && last_sev != -1)
+   if (  is_range
+      && last_sev != -1)
    {
       buf[len - 1] = '-';  // change last comma to a dash
       len         += snprintf(&buf[len], size - len, "%d", last_sev);
