@@ -3,26 +3,24 @@
  * Parses the options from the config file.
  *
  * @author  Ben Gardner
- * @author  Guy Maurel since version 0.62 for uncrustify4Qt
- *          October 2015, 2016
+ * @author  Guy Maurel October 2015, 2021
  * @author  Matthew Woehlke since version 0.67
  * @license GPL v2+
  */
+
 #include "option.h"
 
 #include "keywords.h"
-#include "option_enum.h"
+#include "language_names.h"
 #include "uncrustify.h"
-#include "uncrustify_limits.h"
-#include "uncrustify_types.h"
 #include "uncrustify_version.h"
 
 #include <fstream>
 #include <unordered_map>
 
-#include <cctype>
-#include <cstdarg>
-#include <cstring>
+#include <cctype>                    // to get std::tolower
+#include <cstdarg>                   // to get va_start, va_end
+
 
 namespace uncrustify
 {
@@ -89,9 +87,8 @@ static const char *DOC_TEXT_END = u8R"___(
 std::vector<OptionGroup>                         option_groups;
 std::unordered_map<std::string, GenericOption *> option_map;
 
-#define LOG_CONFIG(...)                            \
-   do { log_config(); LOG_FMT(LNOTE, __VA_ARGS__); \
-   } while (0)
+#define LOG_CONFIG(...) \
+   log_config(); LOG_FMT(LNOTE, __VA_ARGS__);
 
 
 //-----------------------------------------------------------------------------
@@ -156,7 +153,9 @@ std::string to_lower(const std::string &in)
 //-----------------------------------------------------------------------------
 bool is_arg_sep(int ch)
 {
-   return(isspace(ch) || ch == ',' || ch == '=');
+   return(  isspace(ch)
+         || ch == ','
+         || ch == '=');
 }
 
 
@@ -179,13 +178,15 @@ std::vector<std::string> split_args(std::string in, const char *filename,
    while (n < k)
    {
       // Skip leading space
-      while (n < k && is_sep(in[n]))
+      while (  n < k
+            && is_sep(in[n]))
       {
          ++n;
       }
 
       // Detect comments or trailing space
-      if (n >= k || in[n] == '#')
+      if (  n >= k
+         || in[n] == '#')
       {
          break;
       }
@@ -197,7 +198,8 @@ std::vector<std::string> split_args(std::string in, const char *filename,
 
          for ((void)n; in[n] != *quote; ++n)
          {
-            if (n < k && in[n] == '\\')
+            if (  n < k
+               && in[n] == '\\')
             {
                in.erase(n, 1);
                --k;
@@ -213,7 +215,8 @@ std::vector<std::string> split_args(std::string in, const char *filename,
 
          out.push_back(in.substr(start, n - start));
 
-         if (++n < k && !is_sep(in[n]))
+         if (  ++n < k
+            && !is_sep(in[n]))
          {
             OptionWarning w{ filename };
             w("unexpected text following quoted-string");
@@ -224,7 +227,10 @@ std::vector<std::string> split_args(std::string in, const char *filename,
       // Extract anything else
       const auto start = n;
 
-      for ((void)n; n < k && !is_sep(in[n]); ++n)
+      for ((void)n;
+           (  n < k
+           && !is_sep(in[n]));
+           ++n)
       {
          if (in[n] == '\\')
          {
@@ -254,14 +260,18 @@ bool is_path_relative(const std::string &path)
 #ifdef WIN32
    // Check for partition labels as indication for an absolute path
    // 'X:\path\to\file' style absolute disk path
-   if (path.size() > 1 && isalpha(path[0]) && path[1] == ':')
+   if (  path.size() > 1
+      && isalpha(path[0])
+      && path[1] == ':')
    {
       return(false);
    }
 
-   // Check for double backslashs as indication for a network path
+   // Check for double backslashes as indication for a network path
    // '\\server\path\to\file style' absolute UNC path
-   if (path.size() > 1 && path[0] == '\\' && path[1] == '\\')
+   if (  path.size() > 1
+      && path[0] == '\\'
+      && path[1] == '\\')
    {
       return(false);
    }
@@ -279,7 +289,9 @@ void print_description(FILE *pfile, std::string description,
 {
    // Descriptions always start with a '\n', so skip the first character
    for (std::string::size_type start = 1, length = description.length();
-        start != std::string::npos && start < length; ++start)
+        (  start != std::string::npos
+        && start < length);
+        ++start)
    {
       // Check for empty line so we can squelch trailing whitespace
       if (description[start] == '\n')
@@ -315,8 +327,7 @@ bool process_option_line_compat_0_68(const std::string              &cmd,
 } // process_option_line_compat_0_68
 
 
-bool process_option_line_compat_0_70(const std::string &cmd,
-                                     const char        *filename)
+bool process_option_line_compat_0_70(const std::string &cmd, const char *filename)
 {
    if (cmd == "sp_word_brace")                     // Issue #2428
    {
@@ -330,6 +341,96 @@ bool process_option_line_compat_0_70(const std::string &cmd,
    return(false);
 } // process_option_line_compat_0_70
 
+
+bool process_option_line_compat_0_73(const std::string &cmd, const char *filename)
+{
+   if (cmd == "indent_sing_line_comments")         // Issue #3249
+   {
+      OptionWarning w{ filename, OptionWarning::MINOR };
+      w("option '%s' is deprecated; did you want to use '%s' instead?",
+        cmd.c_str(), options::indent_single_line_comments_before.name());
+
+      //UNUSED(options::indent_single_line_comments_before.read(args[1].c_str()));
+      return(true);
+   }
+
+   if (cmd == "sp_before_tr_emb_cmt")              // Issue #3339
+   {
+      OptionWarning w{ filename, OptionWarning::MINOR };
+      w("option '%s' is deprecated; did you want to use '%s' instead?",
+        cmd.c_str(), options::sp_before_tr_cmt.name());
+
+      //UNUSED(options::sp_before_tr_cmt.read(args[1].c_str()));
+      return(true);
+   }
+
+   if (cmd == "sp_num_before_tr_emb_cmt")          // Issue #3339
+   {
+      OptionWarning w{ filename, OptionWarning::MINOR };
+      w("option '%s' is deprecated; did you want to use '%s' instead?",
+        cmd.c_str(), options::sp_num_before_tr_cmt.name());
+
+      //UNUSED(options::sp_num_before_tr_cmt.read(args[1].c_str()));
+      return(true);
+   }
+   return(false);
+} // process_option_line_compat_0_73
+
+
+bool process_option_line_compat_0_74(const std::string &cmd, const char *filename)
+{
+   if (cmd == "sp_type_question")         // PR #3638
+   {
+      OptionWarning w{ filename, OptionWarning::MINOR };
+      w("option '%s' is deprecated; did you want to use '%s' instead?",
+        cmd.c_str(), options::sp_before_ptr_star.name());
+
+      return(true);
+   }
+   return(false);
+} // process_option_line_compat_0_74
+
+
+bool process_option_line_compat_0_75(const std::string &cmd, const char *filename)
+{
+   if (cmd == "pp_space")
+   {
+      OptionWarning w{ filename, OptionWarning::MINOR };
+      w("option '%s' is deprecated; it has been replaced by '%s'.",
+        cmd.c_str(), options::pp_space_after.name());
+
+      return(true);
+   }
+
+   if (cmd == "pp_space_before")
+   {
+      OptionWarning w{ filename, OptionWarning::MINOR };
+      w("option '%s' is deprecated; it was a temporary option used\n"
+        "during the development of version 0.76. Use '%s' and '%s' instead.",
+        cmd.c_str(), options::pp_indent.name(), options::pp_indent_count.name());
+
+      return(true);
+   }
+   return(false);
+} // process_option_line_compat_0_75
+
+
+bool process_option_line_compat_0_76(const std::string &cmd, const std::vector<std::string> &args, const char *filename)
+{
+   if (cmd == "nl_func_var_def_blk")
+   {
+      OptionWarning w{ filename, OptionWarning::MINOR };
+      w("option '%s' is deprecated; it has been replaced by '%s'.\n"
+        "You can also use '%s' for additional functionality",
+        cmd.c_str(), options::nl_var_def_blk_end_func_top.name(),
+        options::nl_var_def_blk_end.name());
+
+      UNUSED(options::nl_var_def_blk_end_func_top.read(args[1].c_str()));
+      return(true);
+   }
+   return(false);
+} // process_option_line_compat_0_76
+
 } // namespace
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -340,10 +441,7 @@ bool process_option_line_compat_0_70(const std::string &cmd,
 //-----------------------------------------------------------------------------
 OptionWarning::OptionWarning(const char *filename, Severity severity)
 {
-   if (severity != MINOR)
-   {
-      ++cpd.error_count;
-   }
+   UNUSED(severity);
 
    if (cpd.line_number != 0)
    {
@@ -359,10 +457,8 @@ OptionWarning::OptionWarning(const char *filename, Severity severity)
 //-----------------------------------------------------------------------------
 OptionWarning::OptionWarning(const GenericOption *opt, Severity severity)
 {
-   if (severity != MINOR)
-   {
-      ++cpd.error_count;
-   }
+   UNUSED(severity);
+
    fprintf(stderr, "Option<%s>: at %s:%d: ", to_string(opt->type()),
            cpd.filename.c_str(), cpd.line_number);
 }
@@ -462,7 +558,8 @@ bool read_number(const char *in, Option<T> &out)
    char       *c;
    const auto val = std::strtol(in, &c, 10);
 
-   if (*c == 0 && out.validate(val))
+   if (  *c == 0
+      && out.validate(val))
    {
       out.m_val = static_cast<T>(val);
       return(true);
@@ -861,7 +958,8 @@ void process_option_line(const std::string &config_line, const char *filename,
    // Check for necessary arguments
    const auto &cmd = to_lower(args.front());
 
-   if (cmd == "set" || cmd == "file_ext")
+   if (  cmd == "set"
+      || cmd == "file_ext")
    {
       if (args.size() < 3)
       {
@@ -936,7 +1034,7 @@ void process_option_line(const std::string &config_line, const char *filename,
       else if (is_path_relative(include_path))
       {
          // include is a relative path to the current config file
-         unc_text ut = std::string{ filename };
+         UncText ut = std::string{ filename };
          ut.resize(static_cast<unsigned>(path_dirname_len(filename)));
          ut.append(include_path);
          UNUSED(load_option_file(ut.c_str(), compat_level));
@@ -1009,6 +1107,38 @@ void process_option_line(const std::string &config_line, const char *filename,
             return;
          }
       }
+
+      if (compat_level < option_level(0, 74))
+      {
+         if (process_option_line_compat_0_73(cmd, filename))
+         {
+            return;
+         }
+      }
+
+      if (compat_level < option_level(0, 75))
+      {
+         if (process_option_line_compat_0_74(cmd, filename))
+         {
+            return;
+         }
+      }
+
+      if (compat_level < option_level(0, 76))
+      {
+         if (process_option_line_compat_0_75(cmd, filename))
+         {
+            return;
+         }
+      }
+
+      if (compat_level < option_level(0, 77))
+      {
+         if (process_option_line_compat_0_76(cmd, args, filename))
+         {
+            return;
+         }
+      }
       const auto oi = option_map.find(cmd);
 
       if (oi == option_map.end())
@@ -1045,18 +1175,43 @@ bool load_option_file(const char *filename, int compat_level)
       OptionWarning w{ filename };
       w("file could not be opened: %s (%d)\n",
         strerror(errno), errno);
-      return(false);
+      exit(EX_SOFTWARE);
    }
    // Read in the file line by line
    std::string line;
 
    while (std::getline(in, line))
    {
+      // check all characters of the line
+      size_t howmany = line.length();
+      int    ch;
+
+      for (size_t n = 0; n < howmany; n++)
+      {
+         ch = line[n];
+
+         // do not check characters in comment part of line
+         if ('#' == ch)
+         {
+            break;
+         }
+
+         // ch >= 0 && ch <= 255
+         if (  ch < 0
+            || ch > 255)
+         {
+            // error
+            // related to PR #3298
+            fprintf(stderr, "%s: line %u: Character at position %zu, is not printable.\n", filename, cpd.line_number + 1, n + 1);
+            exit(EX_SOFTWARE);
+         }
+      }
+
       ++cpd.line_number;
       process_option_line(line, filename, compat_level);
    }
    return(true);
-}
+} // load_option_file
 
 
 //-----------------------------------------------------------------------------
@@ -1160,8 +1315,8 @@ void save_option_file(FILE *pfile, bool with_doc, bool minimal)
    {
       fprintf(pfile, "%s", DOC_TEXT_END);
    }
-   print_keywords(pfile);    // Print custom keywords
-   print_extensions(pfile);  // Print custom file extensions
+   print_custom_keywords(pfile);   // Print custom keywords
+   print_extensions(pfile);        // Print custom file extensions
 
    fprintf(pfile, "# option(s) with 'not default' value: %d%s#%s",
            non_default_values, eol_marker, eol_marker);
