@@ -1,6 +1,6 @@
 /**
  * @file parens.h
- * prototypes for parens.c
+ * prototypes for parens.cpp
  *
  * @author  Ben Gardner
  * @license GPL v2+
@@ -12,7 +12,13 @@
 
 
 //! add parenthesis
-void do_parens(void);
+void do_parens();
+
+
+void do_parens_assign();
+
+
+void do_parens_return();
 
 
 #endif /* PARENS_H_INCLUDED */
