@@ -54,20 +54,21 @@ static const char *pcf_names[] =
    "IN_FCN_CTOR",       // 42                    Issue #2152
    "IN_TRY_BLOCK",      // 43                    Issue #1734
    "INCOMPLETE",        // 44
-   "WF_IF",             // 45
+   "IN_LAMBDA",         // 45
+   "WF_IF",             // 46
+   "NOT_POSSIBLE",      // 47
+   "IN_CONDITIONAL",    // 48                    Issue #3558
+   "OC_IN_BLOCK",       // 49
+   "CONT_LINE",         // 50
 };
 
 
-std::string pcf_flags_str(pcf_flags_t flags)
+std::string pcf_flags_str(PcfFlags flags)
 {
    char buffer[64];
 
    // Generate hex representation first
-#ifdef WIN32
-   snprintf(buffer, 63, "[");
-#else // not WIN32
    snprintf(buffer, 63, "[0x%llx:", (long long unsigned int)(flags));
-#endif // ifdef WIN32
 
    // Add human-readable names
    auto out   = std::string{ buffer };
@@ -75,7 +76,7 @@ std::string pcf_flags_str(pcf_flags_t flags)
 
    for (size_t i = 0; i < ARRAY_SIZE(pcf_names); ++i)
    {
-      if (flags & static_cast<pcf_flag_e>(pcf_bit(i)))
+      if (flags & static_cast<E_PcfFlag>(pcf_bit(i)))
       {
          if (first)
          {
@@ -94,11 +95,11 @@ std::string pcf_flags_str(pcf_flags_t flags)
 }
 
 
-void log_pcf_flags(log_sev_t sev, pcf_flags_t flags)
+void log_pcf_flags(log_sev_t sev, PcfFlags flags)
 {
    if (!log_sev_on(sev))
    {
       return;
    }
-   log_fmt(sev, "%s\n", pcf_flags_str(flags).c_str());
+   log_fmt(sev, "   chunk flags: %s\n", pcf_flags_str(flags).c_str());
 }
