@@ -9,7 +9,7 @@
 #ifndef C_PARSE_PROTOTYPES_H_INCLUDED
 #define C_PARSE_PROTOTYPES_H_INCLUDED
 
-#include "chunk_list.h"
+#include "chunk.h"
 #include "log_rules.h"
 #include "uncrustify_types.h"
 
@@ -54,6 +54,8 @@ static inline size_t calc_next_tab_column(size_t col, size_t tabsize)
  */
 static inline size_t next_tab_column(size_t col)
 {
+   constexpr static auto LCURRENT = LINDENT;
+
    log_rule_B("output_tab_size");
    return(calc_next_tab_column(col, uncrustify::options::output_tab_size()));
 }
