@@ -10,14 +10,12 @@
 #ifndef REMOVE_EXTRA_RETURNS_H_INCLUDED
 #define REMOVE_EXTRA_RETURNS_H_INCLUDED
 
-#include "chunk_list.h"
-
 
 /**
  * @brief Remove unnecessary returns
  * that is remove 'return;' that appears as the last statement in a function
  */
-void remove_extra_returns(void);
+void remove_extra_returns();
 
 
 #endif /* REMOVE_EXTRA_RETURNS_H_INCLUDED */
