@@ -8,12 +8,13 @@
 
 #include "sorting.h"
 
-#include "chunk_list.h"
-#include "log_rules.h"
 #include "newlines.h"
 #include "prototypes.h"
 
 #include <regex>
+#include <unordered_map>
+
+constexpr static auto LCURRENT = LSORT;
 
 using namespace uncrustify;
 
@@ -36,7 +37,9 @@ struct include_category
 };
 
 
-include_category *include_categories[kIncludeCategoriesCount];
+include_category                 *include_categories[kIncludeCategoriesCount];
+unordered_map<Chunk *, int>      chunk_priority_cache;
+unordered_map<std::string, bool> filename_without_ext_cache;
 
 
 /**
@@ -49,15 +52,13 @@ include_category *include_categories[kIncludeCategoriesCount];
  * @retval  > 0
  * @retval  < 0
  */
-static int compare_chunks(chunk_t *pc1, chunk_t *pc2, bool tcare = false);
+static int compare_chunks(Chunk *pc1, Chunk *pc2, bool tcare);
 
 
 /**
- * Sorting should be pretty rare and should usually only include a few chunks.
- * We need to minimize the number of swaps, as those are expensive.
- * So, we do a min sort.
+ * Sort all of the chunks in O(n log n) time with a maximum of O(n) swaps
  */
-static void do_the_sort(chunk_t **chunks, size_t num_chunks);
+static void do_the_sort(Chunk **chunks, size_t num_chunks);
 
 
 #define MARK_CHANGE()    mark_change(__func__, __LINE__)
@@ -96,6 +97,9 @@ static void prepare_categories()
 
 static void cleanup_categories()
 {
+   chunk_priority_cache.clear();
+   filename_without_ext_cache.clear();
+
    for (auto &include_category : include_categories)
    {
       if (include_category == nullptr)
@@ -108,20 +112,28 @@ static void cleanup_categories()
 }
 
 
-static int get_chunk_priority(chunk_t *pc)
+static int get_chunk_priority(Chunk *pc)
 {
+   if (chunk_priority_cache.count(pc) > 0)
+   {
+      return(chunk_priority_cache[pc]);
+   }
+   int category = kIncludeCategoriesCount;
+
    for (int i = 0; i < kIncludeCategoriesCount; i++)
    {
       if (include_categories[i] != nullptr)
       {
-         if (std::regex_match(pc->text(), include_categories[i]->regex))
+         if (std::regex_match(pc->Text(), include_categories[i]->regex))
          {
-            return(i);
+            category = i;
+            break;
          }
       }
    }
 
-   return(kIncludeCategoriesCount);
+   chunk_priority_cache[pc] = category;
+   return(category);
 }
 
 
@@ -130,11 +142,16 @@ static int get_chunk_priority(chunk_t *pc)
  */
 static bool text_contains_filename_without_ext(const char *text)
 {
+   if (filename_without_ext_cache.count(text) > 0)
+   {
+      return(filename_without_ext_cache[text]);
+   }
    std::string filepath             = cpd.filename;
    size_t      slash_idx            = filepath.find_last_of("/\\");
    std::string filename_without_ext = filepath;
 
-   if (slash_idx != std::string::npos && slash_idx < (filepath.size() - 1))
+   if (  slash_idx != std::string::npos
+      && slash_idx < (filepath.size() - 1))
    {
       std::string filename = filepath.substr(slash_idx + 1);
       size_t      dot_idx  = filename.find_last_of('.');
@@ -144,17 +161,18 @@ static bool text_contains_filename_without_ext(const char *text)
    const std::string sanitized_filename = std::regex_replace(filename_without_ext, special_chars, R"(\$&)");
    const std::regex  filename_pattern   = std::regex("\\S?" + sanitized_filename + "\\b.*");
 
-   return(std::regex_match(text, filename_pattern));
+   filename_without_ext_cache[text] = std::regex_match(text, filename_pattern);
+   return(filename_without_ext_cache[text]);
 }
 
 
 /**
  * Get chunk text without the extension.
  */
-static unc_text get_text_without_ext(const unc_text &chunk_text)
+static UncText get_text_without_ext(const UncText &chunk_text)
 {
-   unc_text result = chunk_text;
-   int      idx    = result.rfind(".", result.size() - 1);
+   UncText result = chunk_text;
+   int     idx    = result.rfind(".", result.size() - 1);
 
    if (idx == -1)
    {
@@ -166,9 +184,9 @@ static unc_text get_text_without_ext(const unc_text &chunk_text)
 
 
 /**
- * Returns true if unc_text has "." which implies extension.
+ * Returns true if UncText has "." which implies extension.
  */
-static bool has_dot(const unc_text &chunk_text)
+static bool has_dot(const UncText &chunk_text)
 {
    int idx = chunk_text.rfind(".", chunk_text.size() - 1);
 
@@ -179,31 +197,32 @@ static bool has_dot(const unc_text &chunk_text)
 /**
  * Returns chunk string required for sorting.
  */
-static unc_text chunk_sort_str(chunk_t *pc)
+static UncText chunk_sort_str(Chunk *pc)
 {
-   if (get_chunk_parent_type(pc) == CT_PP_INCLUDE)
+   if (pc->GetParentType() == CT_PP_INCLUDE)
    {
-      return(unc_text{ pc->str, 0, pc->len() - 1 });
+      return(UncText{ pc->GetStr(), 0, pc->Len() - 1 });
    }
-   return(pc->str);
+   return(pc->GetStr());
 }
 
 
 //! Compare two chunks
-static int compare_chunks(chunk_t *pc1, chunk_t *pc2, bool tcare)
+static int compare_chunks(Chunk *pc1, Chunk *pc2, bool tcare)
 {
    LOG_FUNC_ENTRY();
    LOG_FMT(LSORT, "%s(%d): @begin pc1->len is %zu, line is %zu, column is %zu\n",
-           __func__, __LINE__, pc1->len(), pc1->orig_line, pc1->orig_col);
+           __func__, __LINE__, pc1->Len(), pc1->GetOrigLine(), pc1->GetOrigCol());
    LOG_FMT(LSORT, "%s(%d): @begin pc2->len is %zu, line is %zu, column is %zu\n",
-           __func__, __LINE__, pc2->len(), pc2->orig_line, pc2->orig_col);
+           __func__, __LINE__, pc2->Len(), pc2->GetOrigLine(), pc2->GetOrigCol());
 
    if (pc1 == pc2) // same chunk is always identical thus return 0 differences
    {
       return(0);
    }
 
-   while (pc1 != nullptr && pc2 != nullptr)
+   while (  pc1->IsNotNullChunk()
+         && pc2->IsNotNullChunk())
    {
       auto const &s1_ext = chunk_sort_str(pc1);
       auto const &s2_ext = chunk_sort_str(pc2);
@@ -218,11 +237,13 @@ static int compare_chunks(chunk_t *pc1, chunk_t *pc2, bool tcare)
          bool s1_contains_filename = text_contains_filename_without_ext(s1.c_str());
          bool s2_contains_filename = text_contains_filename_without_ext(s2.c_str());
 
-         if (s1_contains_filename && !s2_contains_filename)
+         if (  s1_contains_filename
+            && !s2_contains_filename)
          {
             return(-1);
          }
-         else if (!s1_contains_filename && s2_contains_filename)
+         else if (  !s1_contains_filename
+                 && s2_contains_filename)
          {
             return(1);
          }
@@ -234,11 +255,13 @@ static int compare_chunks(chunk_t *pc1, chunk_t *pc2, bool tcare)
          const bool s1_has_dot = has_dot(s1_ext);
          const bool s2_has_dot = has_dot(s2_ext);
 
-         if (s1_has_dot && !s2_has_dot)
+         if (  s1_has_dot
+            && !s2_has_dot)
          {
             return(1);
          }
-         else if (!s1_has_dot && s2_has_dot)
+         else if (  !s1_has_dot
+                 && s2_has_dot)
          {
             return(-1);
          }
@@ -248,11 +271,13 @@ static int compare_chunks(chunk_t *pc1, chunk_t *pc2, bool tcare)
       {
          log_rule_B("mod_sort_incl_import_prioritize_angle_over_quotes");
 
-         if (s1.startswith("<") && s2.startswith("\""))
+         if (  s1.startswith("<")
+            && s2.startswith("\""))
          {
             return(-1);
          }
-         else if (s1.startswith("\"") && s2.startswith("<"))
+         else if (  s1.startswith("\"")
+                 && s2.startswith("<"))
          {
             return(1);
          }
@@ -265,11 +290,11 @@ static int compare_chunks(chunk_t *pc1, chunk_t *pc2, bool tcare)
          return(ppc1 - ppc2);
       }
       LOG_FMT(LSORT, "%s(%d): text is %s, pc1->len is %zu, line is %zu, column is %zu\n",
-              __func__, __LINE__, pc1->text(), pc1->len(), pc1->orig_line, pc1->orig_col);
+              __func__, __LINE__, pc1->Text(), pc1->Len(), pc1->GetOrigLine(), pc1->GetOrigCol());
       LOG_FMT(LSORT, "%s(%d): text is %s, pc2->len is %zu, line is %zu, column is %zu\n",
-              __func__, __LINE__, pc2->text(), pc2->len(), pc2->orig_line, pc2->orig_col);
+              __func__, __LINE__, pc2->Text(), pc2->Len(), pc2->GetOrigLine(), pc2->GetOrigCol());
 
-      int ret_val = unc_text::compare(s1, s2, std::min(s1.size(), s2.size()), tcare);
+      int ret_val = UncText::compare(s1, s2, std::min(s1.size(), s2.size()), tcare);
       LOG_FMT(LSORT, "%s(%d): ret_val is %d\n",
               __func__, __LINE__, ret_val);
 
@@ -278,52 +303,53 @@ static int compare_chunks(chunk_t *pc1, chunk_t *pc2, bool tcare)
          return(ret_val);
       }
 
-      if (pc1->len() != pc2->len())
+      if (pc1->Len() != pc2->Len())
       {
-         return(pc1->len() - pc2->len());
+         return(pc1->Len() - pc2->Len());
       }
       // Same word, same length. Step to the next chunk.
-      pc1 = chunk_get_next(pc1);
+      pc1 = pc1->GetNext();
       LOG_FMT(LSORT, "%s(%d): text is %s, pc1->len is %zu, line is %zu, column is %zu\n",
-              __func__, __LINE__, pc1->text(), pc1->len(), pc1->orig_line, pc1->orig_col);
+              __func__, __LINE__, pc1->Text(), pc1->Len(), pc1->GetOrigLine(), pc1->GetOrigCol());
 
-      if (chunk_is_token(pc1, CT_MEMBER))
+      if (pc1->Is(CT_MEMBER))
       {
-         pc1 = chunk_get_next(pc1);
+         pc1 = pc1->GetNext();
          LOG_FMT(LSORT, "%s(%d): text is %s, pc1->len is %zu, line is %zu, column is %zu\n",
-                 __func__, __LINE__, pc1->text(), pc1->len(), pc1->orig_line, pc1->orig_col);
+                 __func__, __LINE__, pc1->Text(), pc1->Len(), pc1->GetOrigLine(), pc1->GetOrigCol());
       }
-      pc2 = chunk_get_next(pc2);
+      pc2 = pc2->GetNext();
       LOG_FMT(LSORT, "%s(%d): text is %s, pc2->len is %zu, line is %zu, column is %zu\n",
-              __func__, __LINE__, pc2->text(), pc2->len(), pc2->orig_line, pc2->orig_col);
+              __func__, __LINE__, pc2->Text(), pc2->Len(), pc2->GetOrigLine(), pc2->GetOrigCol());
 
-      if (chunk_is_token(pc2, CT_MEMBER))
+      if (pc2->Is(CT_MEMBER))
       {
-         pc2 = chunk_get_next(pc2);
+         pc2 = pc2->GetNext();
          LOG_FMT(LSORT, "%s(%d): text is %s, pc2->len is %zu, line is %zu, column is %zu\n",
-                 __func__, __LINE__, pc2->text(), pc2->len(), pc2->orig_line, pc2->orig_col);
+                 __func__, __LINE__, pc2->Text(), pc2->Len(), pc2->GetOrigLine(), pc2->GetOrigCol());
       }
       LOG_FMT(LSORT, "%s(%d): >>>text is %s, pc1->len is %zu, line is %zu, column is %zu\n",
-              __func__, __LINE__, pc1->text(), pc1->len(), pc1->orig_line, pc1->orig_col);
+              __func__, __LINE__, pc1->Text(), pc1->Len(), pc1->GetOrigLine(), pc1->GetOrigCol());
       LOG_FMT(LSORT, "%s(%d): >>>text is %s, pc2->len is %zu, line is %zu, column is %zu\n",
-              __func__, __LINE__, pc2->text(), pc2->len(), pc2->orig_line, pc2->orig_col);
+              __func__, __LINE__, pc2->Text(), pc2->Len(), pc2->GetOrigLine(), pc2->GetOrigCol());
 
-      // If we hit a newline or nullptr, we are done
-      if (  pc1 == nullptr
-         || chunk_is_newline(pc1)
-         || pc2 == nullptr
-         || chunk_is_newline(pc2))
+      // If we hit a newline or null chuck, we are done
+      if (  pc1->IsNullChunk()
+         || pc1->IsNewline()
+         || pc2->IsNullChunk()
+         || pc2->IsNewline())
       {
          break;
       }
    }
 
-   if (pc1 == nullptr || !chunk_is_newline(pc2))
+   if (  pc1->IsNullChunk()
+      || !pc2->IsNewline())
    {
       return(-1);
    }
 
-   if (!chunk_is_newline(pc1))
+   if (!pc1->IsNewline())
    {
       return(1);
    }
@@ -332,11 +358,9 @@ static int compare_chunks(chunk_t *pc1, chunk_t *pc2, bool tcare)
 
 
 /**
- * Sorting should be pretty rare and should usually only include a few chunks.
- * We need to minimize the number of swaps, as those are expensive.
- * So, we do a min sort.
+ * Sort all of the chunks in O(n log n) time with a maximum of O(n) swaps
  */
-static void do_the_sort(chunk_t **chunks, size_t num_chunks)
+static void do_the_sort(Chunk **chunks, size_t num_chunks)
 {
    LOG_FUNC_ENTRY();
 
@@ -345,46 +369,44 @@ static void do_the_sort(chunk_t **chunks, size_t num_chunks)
 
    for (size_t idx = 0; idx < num_chunks; idx++)
    {
-      LOG_FMT(LSORT, " [%s]", chunks[idx]->text());
+      LOG_FMT(LSORT, " [%s]", chunks[idx]->Text());
    }
 
    LOG_FMT(LSORT, "\n");
 
-   size_t start_idx;
-
    log_rule_B("mod_sort_case_sensitive");
    bool take_care = options::mod_sort_case_sensitive();                    // Issue #2091
 
-   for (start_idx = 0; start_idx < (num_chunks - 1); start_idx++)
+   // Sort an array of the chunk positions in order to minimize the number of swaps
+   std::vector<size_t> chunk_positions(num_chunks);
+
+   for (size_t idx = 0; idx < num_chunks; idx++)
    {
-      // Find the index of the minimum value
-      size_t min_idx = start_idx;
+      chunk_positions[idx] = idx;
+   }
 
-      for (size_t idx = start_idx + 1; idx < num_chunks; idx++)
-      {
-         if (compare_chunks(chunks[idx], chunks[min_idx], take_care) < 0)  // Issue #2091
-         {
-            min_idx = idx;
-         }
-      }
+   sort(chunk_positions.begin(), chunk_positions.end(), [chunks, take_care](const size_t &l, const size_t &r) {
+      return(compare_chunks(chunks[l], chunks[r], take_care) < 0);
+   });
 
-      // Swap the lines if the minimum isn't the first entry
-      if (min_idx != start_idx)
+   // Swap the chunk positions
+   for (size_t idx = 0; idx < num_chunks; idx++)
+   {
+      if (chunk_positions[idx] != idx)
       {
-         chunk_swap_lines(chunks[start_idx], chunks[min_idx]);
          log_rule_B("mod_sort_incl_import_grouping_enabled");
 
-         if (options::mod_sort_incl_import_grouping_enabled())
-         {
-            chunk_t *pc = chunks[min_idx];
-            chunks[min_idx]   = chunks[start_idx];
-            chunks[start_idx] = pc;
-         }
-         else
-         {
-            // Don't need to swap, since we only want the side-effects
-            chunks[min_idx] = chunks[start_idx];
-         }
+         const size_t from = chunk_positions[idx];
+         const size_t to   = chunk_positions[from];
+         chunks[from]->SwapLines(chunks[to]);
+
+         Chunk *pc = chunks[from];
+         chunks[from] = chunks[to];
+         chunks[to]   = pc;
+
+         chunk_positions[from] = from;
+         chunk_positions[idx]  = to;
+         idx--;
       }
    }
 } // do_the_sort
@@ -393,7 +415,7 @@ static void do_the_sort(chunk_t **chunks, size_t num_chunks)
 /**
  * Remove blank lines between chunks.
  */
-static void remove_blank_lines_between_imports(chunk_t **chunks, size_t num_chunks)
+static void remove_blank_lines_between_imports(Chunk **chunks, size_t num_chunks)
 {
    LOG_FUNC_ENTRY();
 
@@ -404,8 +426,8 @@ static void remove_blank_lines_between_imports(chunk_t **chunks, size_t num_chun
 
    for (size_t idx = 0; idx < (num_chunks - 1); idx++)
    {
-      chunk_t *chunk1 = chunk_get_next_nl(chunks[idx]);
-      chunk1->nl_count = 1;
+      Chunk *chunk1 = chunks[idx]->GetNextNl();
+      chunk1->SetNlCount(1);
       MARK_CHANGE();
    }
 }
@@ -414,26 +436,27 @@ static void remove_blank_lines_between_imports(chunk_t **chunks, size_t num_chun
 /**
  * Delete chunks on line having chunk.
  */
-static void delete_chunks_on_line_having_chunk(chunk_t *chunk)
+static void delete_chunks_on_line_having_chunk(Chunk *chunk)
 {
    LOG_FUNC_ENTRY();
 
-   chunk_t *pc = chunk_first_on_line(chunk);
+   Chunk *pc = chunk->GetFirstChunkOnLine();
 
-   while (pc != nullptr && !chunk_is_comment(pc))
+   while (  pc->IsNotNullChunk()
+         && !pc->IsComment())
    {
-      chunk_t *next_pc = chunk_get_next(pc);
-      LOG_FMT(LCHUNK, "%s(%d): Removed '%s' on orig_line %zu\n",
-              __func__, __LINE__, pc->text(), pc->orig_line);
+      Chunk *next_pc = pc->GetNext();
+      LOG_FMT(LCHUNK, "%s(%d): Removed '%s' on orig line %zu\n",
+              __func__, __LINE__, pc->Text(), pc->GetOrigLine());
 
-      if (chunk_is_newline(pc))
+      if (pc->IsNewline())
       {
-         chunk_del(pc);
+         Chunk::Delete(pc);
          break;
       }
       else
       {
-         chunk_del(pc);
+         Chunk::Delete(pc);
       }
       pc = next_pc;
    }
@@ -443,7 +466,7 @@ static void delete_chunks_on_line_having_chunk(chunk_t *chunk)
 /**
  * Dedupe import/include directives.
  */
-static void dedupe_imports(chunk_t **chunks, size_t num_chunks)
+static void dedupe_imports(Chunk **chunks, size_t num_chunks)
 {
    LOG_FUNC_ENTRY();
    log_rule_B("mod_sort_case_sensitive");
@@ -457,7 +480,7 @@ static void dedupe_imports(chunk_t **chunks, size_t num_chunks)
       {
          continue;
       }
-      int ret_val = unc_text::compare(s1, s2, std::min(s1.size(), s2.size()), options::mod_sort_case_sensitive());
+      int ret_val = UncText::compare(s1, s2, std::min(s1.size(), s2.size()), options::mod_sort_case_sensitive());
 
       if (ret_val == 0)
       {
@@ -470,11 +493,11 @@ static void dedupe_imports(chunk_t **chunks, size_t num_chunks)
 /**
  * Add blank line before the chunk.
  */
-static void blankline_add_before(chunk_t *pc)
+static void blankline_add_before(Chunk *pc)
 {
-   chunk_t *newline = newline_add_before(chunk_first_on_line(pc));
+   Chunk *newline = newline_add_before(pc->GetFirstChunkOnLine());
 
-   if (newline->nl_count < 2)
+   if (newline->GetNlCount() < 2)
    {
       double_newline(newline);
    }
@@ -484,7 +507,7 @@ static void blankline_add_before(chunk_t *pc)
 /**
  * Group imports.
  */
-static void group_imports_by_adding_newlines(chunk_t **chunks, size_t num_chunks)
+static void group_imports_by_adding_newlines(Chunk **chunks, size_t num_chunks)
 {
    LOG_FUNC_ENTRY();
 
@@ -494,16 +517,17 @@ static void group_imports_by_adding_newlines(chunk_t **chunks, size_t num_chunks
 
    for (size_t idx = 0; idx < num_chunks; idx++)
    {
-      if (chunks[idx]->str.size() > 0)
+      if (chunks[idx]->GetStr().size() > 0)
       {
-         c_idx = chunks[idx]->str.at(0);
+         c_idx = chunks[idx]->GetStr().at(0);
       }
       else
       {
          c_idx = -1;
       }
 
-      if (c_idx_last != c_idx && idx > 0)
+      if (  c_idx_last != c_idx
+         && idx > 0)
       {
          blankline_add_before(chunks[idx]);
       }
@@ -516,9 +540,10 @@ static void group_imports_by_adding_newlines(chunk_t **chunks, size_t num_chunks
 
    for (size_t idx = 0; idx < num_chunks; idx++)
    {
-      chunk_has_dot = has_dot(chunks[idx]->str);
+      chunk_has_dot = has_dot(chunks[idx]->GetStr());
 
-      if (chunk_last_has_dot != chunk_has_dot && idx > 0)
+      if (  chunk_last_has_dot != chunk_has_dot
+         && idx > 0)
       {
          blankline_add_before(chunks[idx]);
       }
@@ -533,7 +558,8 @@ static void group_imports_by_adding_newlines(chunk_t **chunks, size_t num_chunks
    {
       chunk_pri = get_chunk_priority(chunks[idx]);
 
-      if (chunk_pri_last != chunk_pri && idx > 0)
+      if (  chunk_pri_last != chunk_pri
+         && idx > 0)
       {
          blankline_add_before(chunks[idx]);
       }
@@ -549,7 +575,8 @@ static void group_imports_by_adding_newlines(chunk_t **chunks, size_t num_chunks
       auto const &chunk_text = chunk_sort_str(chunks[idx]);
       chunk_has_filename = text_contains_filename_without_ext(chunk_text.c_str());
 
-      if (!chunk_has_filename && last_chunk_has_filename)
+      if (  !chunk_has_filename
+         && last_chunk_has_filename)
       {
          blankline_add_before(chunks[idx]);
       }
@@ -558,50 +585,49 @@ static void group_imports_by_adding_newlines(chunk_t **chunks, size_t num_chunks
 } // group_imports_by_adding_newlines
 
 
-void sort_imports(void)
+void sort_imports()
 {
    LOG_FUNC_ENTRY();
    const int max_number_to_sort                        = 1024;
    const int max_lines_to_check_for_sort_after_include = 128;
    const int max_gap_threshold_between_include_to_sort = 32;
 
-   chunk_t   *chunks[max_number_to_sort];
+   Chunk     *chunks[max_number_to_sort];
    size_t    num_chunks  = 0;
-   chunk_t   *p_last     = nullptr;
-   chunk_t   *p_imp      = nullptr;
-   chunk_t   *p_imp_last = nullptr;
+   Chunk     *p_last     = Chunk::NullChunkPtr;
+   Chunk     *p_imp      = Chunk::NullChunkPtr;
+   Chunk     *p_imp_last = Chunk::NullChunkPtr;
 
    prepare_categories();
 
-   chunk_t *pc = chunk_get_head();
+   Chunk *pc = Chunk::GetHead();
 
    log_rule_B("mod_sort_incl_import_grouping_enabled");
 
-   while (pc != nullptr)
+   while (pc->IsNotNullChunk())
    {
       // Simple optimization to limit the sorting. Any MAX_LINES_TO_CHECK_AFTER_INCLUDE lines after last
       // import is seen are ignore from sorting.
       if (  options::mod_sort_incl_import_grouping_enabled()
-         && p_imp_last != nullptr
-         && (pc->orig_line - p_imp_last->orig_line) > max_lines_to_check_for_sort_after_include)
+         && p_imp_last->IsNotNullChunk()
+         && (pc->GetOrigLine() - p_imp_last->GetOrigLine()) > max_lines_to_check_for_sort_after_include)
       {
          break;
       }
-      chunk_t *next = chunk_get_next(pc);
+      Chunk *next = pc->GetNext();
 
-      if (chunk_is_newline(pc))
+      if (pc->IsNewline())
       {
          bool did_import = false;
 
-         if (  p_imp != nullptr
-            && p_last != nullptr
-            && (  chunk_is_token(p_last, CT_SEMICOLON)
-               || p_imp->flags.test(PCF_IN_PREPROC)))
+         if (  p_imp->IsNotNullChunk()
+            && (  p_last->Is(CT_SEMICOLON)
+               || p_imp->TestFlags(PCF_IN_PREPROC)))
          {
             if (num_chunks < max_number_to_sort)
             {
                LOG_FMT(LSORT, "%s(%d): p_imp is %s\n",
-                       __func__, __LINE__, p_imp->text());
+                       __func__, __LINE__, p_imp->Text());
                chunks[num_chunks++] = p_imp;
             }
             else
@@ -609,8 +635,7 @@ void sort_imports(void)
                fprintf(stderr, "Number of 'import' to be sorted is too big for the current value %d.\n", max_number_to_sort);
                fprintf(stderr, "Please make a report.\n");
                log_flush(true);
-               cpd.error_count++;
-               exit(2);
+               exit(EX_SOFTWARE);
             }
             did_import = true;
          }
@@ -618,11 +643,11 @@ void sort_imports(void)
 
          if (  !did_import
             || (  !options::mod_sort_incl_import_grouping_enabled()
-               && pc->nl_count > 1)
+               && pc->GetNlCount() > 1)
             || (  options::mod_sort_incl_import_grouping_enabled()
-               && p_imp_last != nullptr
-               && (pc->orig_line - p_imp_last->orig_line) > max_gap_threshold_between_include_to_sort)
-            || next == nullptr)
+               && p_imp_last->IsNotNullChunk()
+               && (pc->GetOrigLine() - p_imp_last->GetOrigLine()) > max_gap_threshold_between_include_to_sort)
+            || next->IsNullChunk())
          {
             if (num_chunks > 1)
             {
@@ -643,38 +668,38 @@ void sort_imports(void)
             num_chunks = 0;
          }
          p_imp_last = p_imp;
-         p_imp      = nullptr;
-         p_last     = nullptr;
+         p_imp      = Chunk::NullChunkPtr;
+         p_last     = Chunk::NullChunkPtr;
       }
-      else if (chunk_is_token(pc, CT_IMPORT))
+      else if (pc->Is(CT_IMPORT))
       {
          log_rule_B("mod_sort_import");
 
          if (options::mod_sort_import())
          {
-            p_imp = chunk_get_next(pc);
+            p_imp = pc->GetNext();
          }
       }
-      else if (chunk_is_token(pc, CT_USING))
+      else if (pc->Is(CT_USING))
       {
          log_rule_B("mod_sort_using");
 
          if (options::mod_sort_using())
          {
-            p_imp = chunk_get_next(pc);
+            p_imp = pc->GetNext();
          }
       }
-      else if (chunk_is_token(pc, CT_PP_INCLUDE))
+      else if (pc->Is(CT_PP_INCLUDE))
       {
          log_rule_B("mod_sort_include");
 
          if (options::mod_sort_include())
          {
-            p_imp  = chunk_get_next(pc);
+            p_imp  = pc->GetNext();
             p_last = pc;
          }
       }
-      else if (!chunk_is_comment(pc))
+      else if (!pc->IsComment())
       {
          p_last = pc;
       }
