@@ -15,15 +15,15 @@
  * Marches through the whole file and checks to see how many spaces should be
  * between two chunks
  */
-void space_text(void);
+void space_text();
 
 
 //! Marches through the whole file and adds spaces around nested parenthesis
-void space_text_balance_nested_parens(void);
+void space_text_balance_nested_parens();
 
 
 //! Determines if a space is required between two chunks
-size_t space_needed(chunk_t *first, chunk_t *second);
+size_t space_needed(Chunk *first, Chunk *second);
 
 
 /**
@@ -36,10 +36,10 @@ size_t space_needed(chunk_t *first, chunk_t *second);
  *
  * @return the column difference between the two chunks
  */
-size_t space_col_align(chunk_t *first, chunk_t *second);
+size_t space_col_align(Chunk *first, Chunk *second);
 
 
-void space_add_after(chunk_t *pc, size_t count);
+void space_add_after(Chunk *pc, size_t count);
 
 
 #endif /* SPACE_H_INCLUDED */
