@@ -19,43 +19,44 @@
 
 /**
  * This is an enum of all the different chunks/tokens/elements that the
- * program can work with.  The parser and scanner assigns one of these to
+ * program can work with. The parser and scanner assigns one of these to
  * each chunk/token.
  */
-enum c_token_t
+enum E_Token
 {
    CT_NONE,
    CT_PARENT_NOT_SET,
    CT_EOF,
    CT_UNKNOWN,
 
-   CT_JUNK,          // junk collected when parsing is disabled
+   CT_JUNK,              // junk collected when parsing is disabled
 
-   CT_WHITESPACE,    // whitespace without any newlines
-   CT_SPACE,         // a fixed number of spaces to support weird spacing rules
-   CT_NEWLINE,       // CRA, one or more newlines
-   CT_NL_CONT,       // CRA, backslash-newline
-   CT_FORM_FEED,     // character 12
-   CT_COMMENT_CPP,   // C++ comment (always followed by CT_NEWLINE)
-   CT_COMMENT,       // C-comment, single line
-   CT_COMMENT_MULTI, // Multi-lined comment
-   CT_COMMENT_EMBED, // comment parent_type: non-newline before and after
-   CT_COMMENT_START, // comment parent_type: newline before
-   CT_COMMENT_END,   // comment parent_type: newline after
-   CT_COMMENT_WHOLE, // comment parent_type: newline before and after
-   CT_COMMENT_ENDIF, // C-comment, single line, after ENDIF
+   CT_WHITESPACE,        // whitespace without any newlines
+   CT_SPACE,             // a fixed number of spaces to support weird spacing rules
+   CT_NEWLINE,           // CRA, one or more newlines
+   CT_NL_CONT,           // CRA, backslash-newline
+   CT_FORM_FEED,         // character 12
+   CT_COMMENT_CPP,       // C++ comment (always followed by CT_NEWLINE)
+   CT_COMMENT,           // C-comment, single line
+   CT_COMMENT_MULTI,     // Multi-lined comment
+   CT_COMMENT_EMBED,     // comment parent_type: non-newline before and after
+   CT_COMMENT_START,     // comment parent_type: newline before
+   CT_COMMENT_END,       // comment parent_type: newline after
+   CT_COMMENT_WHOLE,     // comment parent_type: newline before and after
+   CT_COMMENT_CPP_ENDIF, // C++ comment, single line, after #endif or #else
+   CT_COMMENT_ENDIF,     // C-comment, single line, after #endif or #else
 
-   CT_IGNORED,       // a chunk of ignored text
+   CT_IGNORED,           // a chunk of ignored text
 
-   CT_WORD,          // variable, type, function name, etc
+   CT_WORD,              // variable, type, function name, etc
    CT_NUMBER,
    CT_NUMBER_FP,
-   CT_STRING,        // quoted string "hi" or 'a' or <in> for include
-   CT_STRING_MULTI,  // quoted string with embedded newline
-   CT_IF,            // built-in keywords
+   CT_STRING,            // quoted string "hi" or 'a' or <in> for include
+   CT_STRING_MULTI,      // quoted string with embedded newline
+   CT_IF,                // built-in keywords
    CT_ELSE,
    CT_ELSEIF,
-   CT_CONSTEXPR,     // only when preceded by 'if' (otherwise CT_QUALIFIER)
+   CT_CONSTEXPR,         // only when preceded by 'if' (otherwise CT_QUALIFIER)
    CT_FOR,
    CT_WHILE,
    CT_WHILE_OF_DO,
@@ -81,6 +82,7 @@ enum c_token_t
    CT_TYPE_CAST,           // static_cast<type>(exp)
    CT_TYPENAME,            // typename type
    CT_TEMPLATE,            // template<...>
+   CT_PARAMETER_PACK,      // template<typename ... ARGS>
    CT_WHERE_SPEC,          // 'where' : used in C# generic constraint
 
    CT_ASSIGN,              // =, +=, /=, etc
@@ -144,9 +146,9 @@ enum c_token_t
    CT_CLASS_COLON,         // colon after a class def
    CT_CONSTR_COLON,        // colon after a constructor
    CT_D_ARRAY_COLON,       // D named array initializer colon
-   CT_COND_COLON,          // conditional colon in  'b ? t : f'
+   CT_COND_COLON,          // conditional colon in 'b ? t : f'
    CT_WHERE_COLON,         // C# where-constraint colon (after the type)
-   CT_QUESTION,
+   CT_QUESTION,            // conditional question in 'b ? t : f'
    CT_COMMA,
 
    CT_ASM,
@@ -177,7 +179,7 @@ enum c_token_t
    CT_USING,
    CT_USING_STMT,       // using (xxx) ...
    CT_USING_ALIAS,      // using identifier attr(optional) = type-id
-   CT_D_WITH,           // D: paren+braced
+   CT_D_WITH,           // D: parenthetis+braced
    CT_D_MODULE,
    CT_SUPER,
    CT_DELEGATE,
@@ -197,25 +199,31 @@ enum c_token_t
    CT_D_VERSION,        // turns into CT_D_VERSION_IF if not followed by '='
    CT_D_VERSION_IF,     // version(x) { }
 
-   // note for paren/brace/square pairs: close MUST be open + 1
+   // note for parenthetis/brace/square pairs: close MUST be open + 1
    CT_PAREN_OPEN,
    CT_PAREN_CLOSE,
 
    CT_ANGLE_OPEN,       // template<T*>
    CT_ANGLE_CLOSE,
 
-   CT_SPAREN_OPEN,      // 'special' paren after if/for/switch/while/synchronized/catch
+   CT_SPAREN_OPEN,      // 'special' parenthetis after if/for/switch/while/synchronized/catch
    CT_SPAREN_CLOSE,
 
-   CT_PPAREN_OPEN,      // 'protect' paren to protect a type such as (*int)
+   CT_PPAREN_OPEN,      // 'protect' parenthetis to protect a type such as (*int)
    CT_PPAREN_CLOSE,     // used at align_func_param
 
-   CT_FPAREN_OPEN,      // 'function' paren after fcn/macro fcn
+   CT_FPAREN_OPEN,      // 'function' parenthetis after fcn/macro fcn
    CT_FPAREN_CLOSE,
 
-   CT_TPAREN_OPEN,      // 'type' paren used in function types
+   CT_LPAREN_OPEN,      // lambda-declarator parenthetis
+   CT_LPAREN_CLOSE,
+
+   CT_TPAREN_OPEN,      // 'type' parenthetis used in function types
    CT_TPAREN_CLOSE,
 
+   CT_RPAREN_OPEN,      // functor                                    Issue #3914
+   CT_RPAREN_CLOSE,
+
    CT_BRACE_OPEN,       // {...}
    CT_BRACE_CLOSE,
 
@@ -248,6 +256,7 @@ enum c_token_t
    CT_FUNC_WRAP,          // macro that wraps the function name
    CT_PROTO_WRAP,         // macro: "RETVAL PROTO_WRAP( fcn_name, (PARAMS))". Parens for PARAMS are optional.
    CT_MACRO_FUNC,         // function-like macro
+   CT_MACRO_FUNC_CALL,    // function-like macro call
    CT_MACRO,              // a macro def
    CT_QUALIFIER,          // static, const, etc
    CT_EXTERN,             // extern
@@ -262,6 +271,7 @@ enum c_token_t
    CT_TRAILING_RET,       // '->' in 'auto fname(...) -> type;'
                           // '->' in 'auto fname(...) const -> type;'
    CT_BIT_COLON,          // a ':' in a variable declaration
+   CT_ENUM_COLON,         // a ':' in a enum definition
 
    CT_OC_DYNAMIC,
    CT_OC_END,           // ObjC: @end
@@ -304,6 +314,7 @@ enum c_token_t
    CT_PP_ENDIF,         // #endif
    CT_PP_ASSERT,
    CT_PP_EMIT,
+   CT_PP_ENDASM,        // end of assembly code section
    CT_PP_ENDINPUT,
    CT_PP_ERROR,
    CT_PP_FILE,
