@@ -1,6 +1,6 @@
 /**
  * @file tokenize_cleanup.h
- * prototypes for tokenize_cleanup.c
+ * prototypes for tokenize_cleanup.cpp
  *
  * @author  Ben Gardner
  * @license GPL v2+
@@ -19,13 +19,13 @@
  * Note that level info is not yet available, so it is OK to do all
  * processing that doesn't need to know level info. (that's very little!)
  */
-void tokenize_cleanup(void);
+void tokenize_cleanup();
 
 
-void tokenize_trailing_return_types(void);
+void tokenize_trailing_return_types();
 
 
-void split_off_angle_close(chunk_t *pc);
+void split_off_angle_close(Chunk *pc);
 
 
 #endif /* TOKENIZ_CLEANUP_H_INCLUDED */
