@@ -1,5 +1,5 @@
 /**
- * @file unc_text.cpp
+ * @file UncText.cpp
  * A simple class that handles the chunk text.
  *
  * @author  Ben Gardner
@@ -12,6 +12,7 @@
 #include "unicode.h" // encode_utf8()
 
 #include <algorithm>
+#include <cstdint>
 #include <stdexcept>
 
 
@@ -24,21 +25,21 @@ static constexpr const int_fast8_t UTF8_BLOCKS = 6;  // 6 -> max utf8 blocks per
 static size_t fix_len_idx(size_t size, size_t idx, size_t len);
 
 //! converts \n and \r chars are into NL and CR UTF8 symbols before encode_utf8 is called
-static void toLogTextUtf8(int c, unc_text::log_type &container);
+static void toLogTextUtf8(int c, UncText::log_type &container);
 
 /**
  * calculates the size a 'log_type' container needs to have in order to take
- * in values of a 'unc_text::value_type' up to idx
+ * in values of a 'UncText::value_type' up to idx
  * (without \0, with symbols for the converted \n and \r chars)
  *
  * throws if char is greater than 0x7fffffff
  */
-static int getLogTextUtf8Len(unc_text::value_type &c0, size_t end);
+static int getLogTextUtf8Len(UncText::value_type &c0, size_t end);
 
-static int getLogTextUtf8Len(unc_text::value_type &c0, size_t start, size_t end);
+static int getLogTextUtf8Len(UncText::value_type &c0, size_t start, size_t end);
 
 
-static int getLogTextUtf8Len(unc_text::value_type &c0, size_t start, size_t end)
+static int getLogTextUtf8Len(UncText::value_type &c0, size_t start, size_t end)
 {
    size_t c1_idx = 0;
 
@@ -90,13 +91,13 @@ static int getLogTextUtf8Len(unc_text::value_type &c0, size_t start, size_t end)
 } // getLogTextUTF8Len
 
 
-static int getLogTextUtf8Len(unc_text::value_type &c0, size_t end)
+static int getLogTextUtf8Len(UncText::value_type &c0, size_t end)
 {
    return(getLogTextUtf8Len(c0, 0, end));
 }
 
 
-static void toLogTextUtf8(int c, unc_text::log_type &container)
+static void toLogTextUtf8(int c, UncText::log_type &container)
 {
    if (c == '\n')
    {
@@ -122,135 +123,141 @@ static size_t fix_len_idx(size_t size, size_t idx, size_t len)
 }
 
 
-unc_text::unc_text()
+UncText::UncText()
 {
    m_logtext = log_type{ '\0' };
 }
 
 
-unc_text::unc_text(const unc_text &ref)
+UncText::UncText(const UncText &ref)
 {
    set(ref);
 }
 
 
-unc_text::unc_text(const unc_text &ref, size_t idx, size_t len)
+UncText::UncText(const UncText &ref, size_t idx, size_t len)
 {
    set(ref, idx, len);
 }
 
 
-unc_text::unc_text(const char *ascii_text)
+UncText::UncText(const char *ascii_text)
 {
    set(ascii_text);
 }
 
 
-unc_text::unc_text(const std::string &ascii_text)
+UncText::UncText(const std::string &ascii_text)
 {
    set(ascii_text);
 }
 
 
-unc_text::unc_text(const value_type &data, size_t idx, size_t len)
+UncText::UncText(const value_type &data, size_t idx, size_t len)
 {
    set(data, idx, len);
 }
 
 
-size_t unc_text::size() const
+size_t UncText::size() const
 {
    return(m_chars.size());
 }
 
 
-unc_text &unc_text::operator=(int ch)
+UncText &UncText::operator=(int ch)
 {
    set(ch);
    return(*this);
 }
 
 
-unc_text &unc_text::operator=(const unc_text &ref)
+UncText &UncText::operator=(const UncText &ref)
 {
    set(ref);
    return(*this);
 }
 
 
-unc_text &unc_text::operator=(const std::string &ascii_text)
+UncText &UncText::operator=(const std::string &ascii_text)
 {
    set(ascii_text);
    return(*this);
 }
 
 
-unc_text &unc_text::operator=(const char *ascii_text)
+UncText &UncText::operator=(const char *ascii_text)
 {
    set(ascii_text);
    return(*this);
 }
 
 
-unc_text &unc_text::operator+=(int ch)
+UncText &UncText::operator+=(int ch)
 {
    append(ch);
    return(*this);
 }
 
 
-unc_text &unc_text::operator+=(const unc_text &ref)
+UncText &UncText::operator+=(const UncText &ref)
 {
    append(ref);
    return(*this);
 }
 
 
-unc_text &unc_text::operator+=(const std::string &ascii_text)
+UncText &UncText::operator+=(const std::string &ascii_text)
 {
    append(ascii_text);
    return(*this);
 }
 
 
-unc_text &unc_text::operator+=(const char *ascii_text)
+UncText &UncText::operator+=(const char *ascii_text)
 {
    append(ascii_text);
    return(*this);
 }
 
 
-const unc_text::value_type &unc_text::get() const
+const UncText::value_type &UncText::get() const
 {
    return(m_chars);
 }
 
 
-int unc_text::operator[](size_t idx) const
+int UncText::operator[](size_t idx) const
 {
    return((idx < m_chars.size()) ? m_chars[idx] : 0);
 }
 
 
-const int &unc_text::at(size_t idx) const
+const int &UncText::at(size_t idx) const
 {
    return(m_chars.at(idx));
 }
 
 
-const int &unc_text::back() const
+int &UncText::at(size_t idx)
+{
+   return(m_chars.at(idx));
+}
+
+
+const int &UncText::back() const
 {
    return(m_chars.back());
 }
 
 
-void unc_text::push_back(int ch)
+void UncText::push_back(int ch)
 {
    append(ch);
 }
 
 
-void unc_text::pop_back()
+void UncText::pop_back()
 {
    if (size() == 0)
    {
@@ -261,7 +268,7 @@ void unc_text::pop_back()
 }
 
 
-void unc_text::pop_front()
+void UncText::pop_front()
 {
    if (size() == 0)
    {
@@ -272,7 +279,7 @@ void unc_text::pop_front()
 }
 
 
-void unc_text::update_logtext()
+void UncText::update_logtext()
 {
    // make a pessimistic guess at the size
    m_logtext.clear();
@@ -287,7 +294,7 @@ void unc_text::update_logtext()
 }
 
 
-int unc_text::compare(const unc_text &ref1, const unc_text &ref2, size_t len, bool tcare)
+int UncText::compare(const UncText &ref1, const UncText &ref2, size_t len, bool tcare)
 {
    const size_t len1    = ref1.size();
    const size_t len2    = ref2.size();
@@ -331,10 +338,10 @@ int unc_text::compare(const unc_text &ref1, const unc_text &ref2, size_t len, bo
    }
    // underflow save: return(len1 - len2);
    return((len1 > len2) ? (len1 - len2) : -static_cast<int>(len2 - len1));
-} // unc_text::compare
+} // UncText::compare
 
 
-bool unc_text::equals(const unc_text &ref) const
+bool UncText::equals(const UncText &ref) const
 {
    const size_t len = size();
 
@@ -355,13 +362,13 @@ bool unc_text::equals(const unc_text &ref) const
 }
 
 
-const char *unc_text::c_str() const
+const char *UncText::c_str() const
 {
    return(reinterpret_cast<const char *>(&m_logtext[0]));
 }
 
 
-void unc_text::set(int ch)
+void UncText::set(int ch)
 {
    m_logtext.clear();
    toLogTextUtf8(ch, m_logtext);
@@ -373,14 +380,14 @@ void unc_text::set(int ch)
 }
 
 
-void unc_text::set(const unc_text &ref)
+void UncText::set(const UncText &ref)
 {
    m_chars   = ref.m_chars;
    m_logtext = ref.m_logtext;
 }
 
 
-void unc_text::set(const unc_text &ref, size_t idx, size_t len)
+void UncText::set(const UncText &ref, size_t idx, size_t len)
 {
    const auto ref_size = ref.size();
 
@@ -405,7 +412,7 @@ void unc_text::set(const unc_text &ref, size_t idx, size_t len)
 }
 
 
-void unc_text::set(const string &ascii_text)
+void UncText::set(const string &ascii_text)
 {
    const size_t len = ascii_text.size();
 
@@ -420,7 +427,7 @@ void unc_text::set(const string &ascii_text)
 }
 
 
-void unc_text::set(const char *ascii_text)
+void UncText::set(const char *ascii_text)
 {
    const size_t len = strlen(ascii_text);
 
@@ -435,7 +442,7 @@ void unc_text::set(const char *ascii_text)
 }
 
 
-void unc_text::set(const value_type &data, size_t idx, size_t len)
+void UncText::set(const value_type &data, size_t idx, size_t len)
 {
    m_chars.resize(len);
 
@@ -452,7 +459,7 @@ void unc_text::set(const value_type &data, size_t idx, size_t len)
 }
 
 
-void unc_text::resize(size_t new_size)
+void UncText::resize(size_t new_size)
 {
    if (size() == new_size)
    {
@@ -468,7 +475,7 @@ void unc_text::resize(size_t new_size)
 }
 
 
-void unc_text::clear()
+void UncText::clear()
 {
    m_logtext.clear();
    m_logtext.push_back('\0');
@@ -478,7 +485,7 @@ void unc_text::clear()
 }
 
 
-void unc_text::insert(size_t idx, int ch)
+void UncText::insert(size_t idx, int ch)
 {
    if (idx >= m_chars.size())
    {
@@ -502,7 +509,7 @@ void unc_text::insert(size_t idx, int ch)
 }
 
 
-void unc_text::insert(size_t idx, const unc_text &ref)
+void UncText::insert(size_t idx, const UncText &ref)
 {
    if (ref.size() == 0)
    {
@@ -529,11 +536,13 @@ void unc_text::insert(size_t idx, const unc_text &ref)
 }
 
 
-void unc_text::append(int ch)
+void UncText::append(int ch)
 {
    m_logtext.pop_back();
 
-   if (ch < 0x80 && ch != '\n' && ch != '\r')
+   if (  ch < 0x80
+      && ch != '\n'
+      && ch != '\r')
    {
       m_logtext.push_back(ch);
    }
@@ -553,7 +562,7 @@ void unc_text::append(int ch)
 }
 
 
-void unc_text::append(const unc_text &ref)
+void UncText::append(const UncText &ref)
 {
    if (ref.size() == 0)
    {
@@ -567,35 +576,38 @@ void unc_text::append(const unc_text &ref)
 }
 
 
-void unc_text::append(const string &ascii_text)
+void UncText::append(const string &ascii_text)
 {
-   unc_text tmp(ascii_text);
+   UncText tmp(ascii_text);
 
    append(tmp);
 }
 
 
-void unc_text::append(const char *ascii_text)
+void UncText::append(const char *ascii_text)
 {
-   unc_text tmp(ascii_text);
+   UncText tmp(ascii_text);
 
    append(tmp);
 }
 
 
-void unc_text::append(const value_type &data, size_t idx, size_t len)
+void UncText::append(const value_type &data, size_t idx, size_t len)
 {
-   unc_text tmp(data, idx, len);
+   UncText tmp(data, idx, len);
 
    append(tmp);
 }
 
 
-bool unc_text::startswith(const char *text, size_t idx) const
+bool UncText::startswith(const char *text, size_t idx) const
 {
    const auto orig_idx = idx;
 
-   for ( ; idx < size() && *text; idx++, text++)
+   for ( ;
+         (  idx < size()
+         && *text);
+         idx++, text++)
    {
       if (*text != m_chars[idx])
       {
@@ -603,16 +615,20 @@ bool unc_text::startswith(const char *text, size_t idx) const
       }
    }
 
-   return(idx != orig_idx && (*text == 0));
+   return(  idx != orig_idx
+         && (*text == 0));
 }
 
 
-bool unc_text::startswith(const unc_text &text, size_t idx) const
+bool UncText::startswith(const UncText &text, size_t idx) const
 {
    size_t     si       = 0;
    const auto orig_idx = idx;
 
-   for ( ; idx < size() && si < text.size(); idx++, si++)
+   for ( ;
+         (  idx < size()
+         && si < text.size());
+         idx++, si++)
    {
       if (text.m_chars[si] != m_chars[idx])
       {
@@ -620,11 +636,12 @@ bool unc_text::startswith(const unc_text &text, size_t idx) const
       }
    }
 
-   return(idx != orig_idx && (si == text.size()));
+   return(  idx != orig_idx
+         && (si == text.size()));
 }
 
 
-int unc_text::find(const char *search_txt, size_t start_idx) const
+int UncText::find(const char *search_txt, size_t start_idx) const
 {
    const size_t t_len = strlen(search_txt); // the length of 'text' we are looking for
    const size_t s_len = size();             // the length of the string we are looking in
@@ -659,7 +676,7 @@ int unc_text::find(const char *search_txt, size_t start_idx) const
 }
 
 
-int unc_text::rfind(const char *search_txt, size_t start_idx) const
+int UncText::rfind(const char *search_txt, size_t start_idx) const
 {
    const size_t t_len = strlen(search_txt); // the length of 'text' we are looking for
    const size_t s_len = size();             // the length of the string we are looking in
@@ -699,7 +716,7 @@ int unc_text::rfind(const char *search_txt, size_t start_idx) const
 }
 
 
-void unc_text::erase(size_t start_idx, size_t len)
+void UncText::erase(size_t start_idx, size_t len)
 {
    if (len == 0)
    {
@@ -726,7 +743,7 @@ void unc_text::erase(size_t start_idx, size_t len)
 }
 
 
-int unc_text::replace(const char *search_text, const unc_text &replace_text)
+int UncText::replace(const char *search_text, const UncText &replace_text)
 {
    const size_t s_len = strlen(search_text);
    const size_t r_len = replace_text.size();
