@@ -2,16 +2,14 @@
  * @file unc_tools.h
  *
  * @author  Guy Maurel
- *          October 2015, 2016, 2017, 2018, 2019
+ *          October 2015, 2023
  * @license GPL v2+
  */
 
 #ifndef UNC_TOOLS_H_INCLUDED
 #define UNC_TOOLS_H_INCLUDED
 
-#include "chunk_list.h"
 #include "prototypes.h"
-#include "uncrustify_types.h"
 
 #if defined DEBUG
 #define PROT_THE_LINE    prot_the_line(__func__, __LINE__, 0, 0);
@@ -19,16 +17,32 @@
 #define PROT_THE_LINE    /* do nothing */;
 #endif
 
+extern char dump_file_name[80];
+
+void set_dump_file_name(const char *name);
+
 
 void prot_the_line(const char *func_name, int theLine, unsigned int actual_line, size_t partNumber);
 
 
-void prot_the_line_pc(chunk_t *pc_sub, const char *func_name, int theLine, unsigned int actual_line, size_t partNumber);
+void prot_the_line_pc(Chunk *pc_sub, const char *func_name, int theLine, unsigned int actual_line, size_t partNumber);
+
+
+void prot_all_lines(const char *func_name, int theLine);
 
 
 void prot_the_source(int theLine);
 
 
+void prot_the_columns(int theLine, unsigned int actual_line);
+
+
+void prot_the_OrigCols(int theLine, unsigned int actual_line);
+
+
+void rebuild_the_line(int theLine, unsigned int actual_line, bool increment = true);
+
+
 void examine_Data(const char *func_name, int theLine, int what);
 
 
@@ -42,4 +56,11 @@ void dump_in(unsigned int type);
 
 size_t get_A_Number();
 
+
+void dump_keyword_for_lang(size_t language_count, chunk_tag_t *keyword_for_lang);
+
+//! This save the next formatting step to a file
+void dump_step(const char *filename, const char *description);
+
+
 #endif /* UNC_TOOLS_H_INCLUDED */
