@@ -25,6 +25,7 @@
  *   --replace
  *   --mtime
  *   --universalindent
+ *   --ds/--dump-steps
  *   -help, -h, --usage, -?
  *
  *
@@ -39,7 +40,7 @@
  *   --file, -f ( use uncrustify( string _file ) )
  *   --show ( use log_type_show_name( bool ) )
  *   --frag ( use uncrustify( string _file, bool frag = true ) )
- *   --type ( use add_keyword( string _type, c_token_t type ) )
+ *   --type ( use add_keyword( string _type, E_Token type ) )
  *   -l ( use uncrustify() )
  *   --parsed, -p  ( use debug() )
  */
@@ -172,7 +173,7 @@ int load_option_fileChar(char *configString)
  * @param tag:  keyword that is going to be added
  * @param type: type of the keyword
  */
-void _add_keyword(string tag, c_token_t type)
+void _add_keyword(string tag, E_Token type)
 {
    if (tag.empty())
    {
@@ -485,10 +486,9 @@ intptr_t _uncrustify(intptr_t _file, lang_flag_e langIDX, bool frag, bool defer)
 {
    // Problem: uncrustify originally is not a lib and uses global vars such as
    // cpd.error_count for the whole program execution
-   // to know if errors occurred during the formating step we reset this var here
-   cpd.error_count = 0;
-   cpd.filename    = "stdin";
-   cpd.frag        = frag;
+   // to know if errors occurred during the formatting step we reset this var here
+   cpd.filename = "stdin";
+   cpd.frag     = frag;
 
    if (langIDX == 0)   // 0 == undefined
    {
@@ -523,8 +523,8 @@ intptr_t _uncrustify(intptr_t _file, lang_flag_e langIDX, bool frag, bool defer)
       return(0);
    }
    // Done reading from stdin
-   LOG_FMT(LSYS, "Parsing: %d bytes (%d chars) from stdin as language %s\n",
-           (int)fm.raw.size(), (int)fm.data.size(),
+   LOG_FMT(LSYS, "Parsing: %zu bytes (%zu chars) from stdin as language %s\n",
+           fm.raw.size(), fm.data.size(),
            language_name_from_flags(cpd.lang_flags));
 
 
@@ -544,7 +544,7 @@ intptr_t _uncrustify(intptr_t _file, lang_flag_e langIDX, bool frag, bool defer)
       return(0);
    }
    // TODO One way to implement the --parsed, -p functionality would
-   // be to let the uncrustify_file function run, throw away the formated
+   // be to let the uncrustify_file function run, throw away the formatted
    // output and return the debug as a string. For this uncrustify_file would
    // need to accept a stream, FILE or a char array pointer in which the output
    // will be stored.
@@ -557,16 +557,11 @@ intptr_t _uncrustify(intptr_t _file, lang_flag_e langIDX, bool frag, bool defer)
    // function which passes the debug output into a dedicated output js target.
    // This therefore would introduce the dependency on the user to always have
    // the output js target available.
-   uncrustify_file(fm, stream, nullptr, defer);
+   uncrustify_file(fm, stream, nullptr, nullptr, defer);
 
    fflush(stream);
    fclose(stream);
 
-   if (cpd.error_count != 0)
-   {
-      LOG_FMT(LWARN, "%d errors occurred during formating\n", cpd.error_count);
-   }
-
    if (len == 0)
    {
       return(0);
@@ -619,7 +614,7 @@ intptr_t _debug(intptr_t _file, lang_flag_e langIDX, bool frag)
    auto formatted_str_ptr = _uncrustify(_file, langIDX, frag, true);
    char *formatted_str    = reinterpret_cast<char *>(formatted_str_ptr);
 
-   // Lazy solution: Throw away the formated file output.
+   // Lazy solution: Throw away the formatted file output.
    // Maybe later add option to return both formatted file string and debug
    // file string together ... somehow.
    free(formatted_str);
@@ -677,10 +672,10 @@ EMSCRIPTEN_BINDINGS(MainModule)
       .value("STRING", option_type_e::STRING);
 
    enum_<iarf_e>("IARF")
-      .value("IGNORE", iarf_e::IGNORE)
-      .value("ADD", iarf_e::ADD)
-      .value("REMOVE", iarf_e::REMOVE)
-      .value("FORCE", iarf_e::FORCE);
+      .value("IGNORE", IARF_IGNORE)
+      .value("ADD", IARF_ADD)
+      .value("REMOVE", IARF_REMOVE)
+      .value("FORCE", IARF_FORCE);
 
    enum_<line_end_e>("LineEnd")
       .value("LF", line_end_e::LF)
@@ -798,305 +793,306 @@ EMSCRIPTEN_BINDINGS(MainModule)
       .value("GUY98", log_sev_t::LGUY98)
       .value("GUY", log_sev_t::LGUY);
 
-   enum_<c_token_t>("TokenType")
-      .value("NONE", c_token_t::CT_NONE)
-      .value("EOF", c_token_t::CT_EOF)
-      .value("UNKNOWN", c_token_t::CT_UNKNOWN)
-      .value("JUNK", c_token_t::CT_JUNK)
-      .value("WHITESPACE", c_token_t::CT_WHITESPACE)
-      .value("SPACE", c_token_t::CT_SPACE)
-      .value("NEWLINE", c_token_t::CT_NEWLINE)
-      .value("NL_CONT", c_token_t::CT_NL_CONT)
-      .value("COMMENT_CPP", c_token_t::CT_COMMENT_CPP)
-      .value("COMMENT", c_token_t::CT_COMMENT)
-      .value("COMMENT_MULTI", c_token_t::CT_COMMENT_MULTI)
-      .value("COMMENT_EMBED", c_token_t::CT_COMMENT_EMBED)
-      .value("COMMENT_START", c_token_t::CT_COMMENT_START)
-      .value("COMMENT_END", c_token_t::CT_COMMENT_END)
-      .value("COMMENT_WHOLE", c_token_t::CT_COMMENT_WHOLE)
-      .value("COMMENT_ENDIF", c_token_t::CT_COMMENT_ENDIF)
-      .value("IGNORED", c_token_t::CT_IGNORED)
-      .value("WORD", c_token_t::CT_WORD)
-      .value("NUMBER", c_token_t::CT_NUMBER)
-      .value("NUMBER_FP", c_token_t::CT_NUMBER_FP)
-      .value("STRING", c_token_t::CT_STRING)
-      .value("STRING_MULTI", c_token_t::CT_STRING_MULTI)
-      .value("IF", c_token_t::CT_IF)
-      .value("ELSE", c_token_t::CT_ELSE)
-      .value("ELSEIF", c_token_t::CT_ELSEIF)
-      .value("FOR", c_token_t::CT_FOR)
-      .value("WHILE", c_token_t::CT_WHILE)
-      .value("WHILE_OF_DO", c_token_t::CT_WHILE_OF_DO)
-      .value("SWITCH", c_token_t::CT_SWITCH)
-      .value("CASE", c_token_t::CT_CASE)
-      .value("DO", c_token_t::CT_DO)
-      .value("SYNCHRONIZED", c_token_t::CT_SYNCHRONIZED)
-      .value("VOLATILE", c_token_t::CT_VOLATILE)
-      .value("TYPEDEF", c_token_t::CT_TYPEDEF)
-      .value("STRUCT", c_token_t::CT_STRUCT)
-      .value("ENUM", c_token_t::CT_ENUM)
-      .value("ENUM_CLASS", c_token_t::CT_ENUM_CLASS)
-      .value("SIZEOF", c_token_t::CT_SIZEOF)
-      .value("DECLTYPE", c_token_t::CT_DECLTYPE)
-      .value("RETURN", c_token_t::CT_RETURN)
-      .value("BREAK", c_token_t::CT_BREAK)
-      .value("UNION", c_token_t::CT_UNION)
-      .value("GOTO", c_token_t::CT_GOTO)
-      .value("CONTINUE", c_token_t::CT_CONTINUE)
-      .value("C_CAST", c_token_t::CT_C_CAST)
-      .value("CPP_CAST", c_token_t::CT_CPP_CAST)
-      .value("D_CAST", c_token_t::CT_D_CAST)
-      .value("TYPE_CAST", c_token_t::CT_TYPE_CAST)
-      .value("TYPENAME", c_token_t::CT_TYPENAME)
-      .value("TEMPLATE", c_token_t::CT_TEMPLATE)
-      .value("WHERE_SPEC", c_token_t::CT_WHERE_SPEC)
-      .value("ASSIGN", c_token_t::CT_ASSIGN)
-      .value("ASSIGN_NL", c_token_t::CT_ASSIGN_NL)
-      .value("SASSIGN", c_token_t::CT_SASSIGN)
-      .value("ASSIGN_DEFAULT_ARG", c_token_t::CT_ASSIGN_DEFAULT_ARG)
-      .value("ASSIGN_FUNC_PROTO", c_token_t::CT_ASSIGN_FUNC_PROTO)
-      .value("COMPARE", c_token_t::CT_COMPARE)
-      .value("SCOMPARE", c_token_t::CT_SCOMPARE)
-      .value("BOOL", c_token_t::CT_BOOL)
-      .value("SBOOL", c_token_t::CT_SBOOL)
-      .value("ARITH", c_token_t::CT_ARITH)
-      .value("SARITH", c_token_t::CT_SARITH)
-      .value("CARET", c_token_t::CT_CARET)
-      .value("DEREF", c_token_t::CT_DEREF)
-      .value("INCDEC_BEFORE", c_token_t::CT_INCDEC_BEFORE)
-      .value("INCDEC_AFTER", c_token_t::CT_INCDEC_AFTER)
-      .value("MEMBER", c_token_t::CT_MEMBER)
-      .value("DC_MEMBER", c_token_t::CT_DC_MEMBER)
-      .value("C99_MEMBER", c_token_t::CT_C99_MEMBER)
-      .value("INV", c_token_t::CT_INV)
-      .value("DESTRUCTOR", c_token_t::CT_DESTRUCTOR)
-      .value("NOT", c_token_t::CT_NOT)
-      .value("D_TEMPLATE", c_token_t::CT_D_TEMPLATE)
-      .value("ADDR", c_token_t::CT_ADDR)
-      .value("NEG", c_token_t::CT_NEG)
-      .value("POS", c_token_t::CT_POS)
-      .value("STAR", c_token_t::CT_STAR)
-      .value("PLUS", c_token_t::CT_PLUS)
-      .value("MINUS", c_token_t::CT_MINUS)
-      .value("AMP", c_token_t::CT_AMP)
-      .value("BYREF", c_token_t::CT_BYREF)
-      .value("POUND", c_token_t::CT_POUND)
-      .value("PREPROC", c_token_t::CT_PREPROC)
-      .value("PREPROC_INDENT", c_token_t::CT_PREPROC_INDENT)
-      .value("PREPROC_BODY", c_token_t::CT_PREPROC_BODY)
-      .value("PP", c_token_t::CT_PP)
-      .value("ELLIPSIS", c_token_t::CT_ELLIPSIS)
-      .value("RANGE", c_token_t::CT_RANGE)
-      .value("NULLCOND", c_token_t::CT_NULLCOND)
-      .value("SEMICOLON", c_token_t::CT_SEMICOLON)
-      .value("VSEMICOLON", c_token_t::CT_VSEMICOLON)
-      .value("COLON", c_token_t::CT_COLON)
-      .value("ASM_COLON", c_token_t::CT_ASM_COLON)
-      .value("CASE_COLON", c_token_t::CT_CASE_COLON)
-      .value("CLASS_COLON", c_token_t::CT_CLASS_COLON)
-      .value("CONSTR_COLON", c_token_t::CT_CONSTR_COLON)
-      .value("D_ARRAY_COLON", c_token_t::CT_D_ARRAY_COLON)
-      .value("COND_COLON", c_token_t::CT_COND_COLON)
-      .value("WHERE_COLON", c_token_t::CT_WHERE_COLON)
-      .value("QUESTION", c_token_t::CT_QUESTION)
-      .value("COMMA", c_token_t::CT_COMMA)
-      .value("ASM", c_token_t::CT_ASM)
-      .value("ATTRIBUTE", c_token_t::CT_ATTRIBUTE)
-      .value("AUTORELEASEPOOL", c_token_t::CT_AUTORELEASEPOOL)
-      .value("OC_AVAILABLE", c_token_t::CT_OC_AVAILABLE)
-      .value("OC_AVAILABLE_VALUE", c_token_t::CT_OC_AVAILABLE_VALUE)
-      .value("CATCH", c_token_t::CT_CATCH)
-      .value("WHEN", c_token_t::CT_WHEN)
-      .value("WHERE", c_token_t::CT_WHERE)
-      .value("CLASS", c_token_t::CT_CLASS)
-      .value("DELETE", c_token_t::CT_DELETE)
-      .value("EXPORT", c_token_t::CT_EXPORT)
-      .value("FRIEND", c_token_t::CT_FRIEND)
-      .value("NAMESPACE", c_token_t::CT_NAMESPACE)
-      .value("PACKAGE", c_token_t::CT_PACKAGE)
-      .value("NEW", c_token_t::CT_NEW)
-      .value("OPERATOR", c_token_t::CT_OPERATOR)
-      .value("OPERATOR_VAL", c_token_t::CT_OPERATOR_VAL)
-      .value("ASSIGN_OPERATOR", c_token_t::CT_ASSIGN_OPERATOR)
-      .value("ACCESS", c_token_t::CT_ACCESS)
-      .value("ACCESS_COLON", c_token_t::CT_ACCESS_COLON)
-      .value("THROW", c_token_t::CT_THROW)
-      .value("NOEXCEPT", c_token_t::CT_NOEXCEPT)
-      .value("TRY", c_token_t::CT_TRY)
-      .value("BRACED_INIT_LIST", c_token_t::CT_BRACED_INIT_LIST)
-      .value("USING", c_token_t::CT_USING)
-      .value("USING_STMT", c_token_t::CT_USING_STMT)
-      .value("USING_ALIAS", c_token_t::CT_USING_ALIAS)
-      .value("D_WITH", c_token_t::CT_D_WITH)
-      .value("D_MODULE", c_token_t::CT_D_MODULE)
-      .value("SUPER", c_token_t::CT_SUPER)
-      .value("DELEGATE", c_token_t::CT_DELEGATE)
-      .value("BODY", c_token_t::CT_BODY)
-      .value("DEBUG", c_token_t::CT_DEBUG)
-      .value("DEBUGGER", c_token_t::CT_DEBUGGER)
-      .value("INVARIANT", c_token_t::CT_INVARIANT)
-      .value("UNITTEST", c_token_t::CT_UNITTEST)
-      .value("UNSAFE", c_token_t::CT_UNSAFE)
-      .value("FINALLY", c_token_t::CT_FINALLY)
-      .value("FIXED", c_token_t::CT_FIXED)
-      .value("IMPORT", c_token_t::CT_IMPORT)
-      .value("D_SCOPE", c_token_t::CT_D_SCOPE)
-      .value("D_SCOPE_IF", c_token_t::CT_D_SCOPE_IF)
-      .value("LAZY", c_token_t::CT_LAZY)
-      .value("D_MACRO", c_token_t::CT_D_MACRO)
-      .value("D_VERSION", c_token_t::CT_D_VERSION)
-      .value("D_VERSION_IF", c_token_t::CT_D_VERSION_IF)
-      .value("PAREN_OPEN", c_token_t::CT_PAREN_OPEN)
-      .value("PAREN_CLOSE", c_token_t::CT_PAREN_CLOSE)
-      .value("ANGLE_OPEN", c_token_t::CT_ANGLE_OPEN)
-      .value("ANGLE_CLOSE", c_token_t::CT_ANGLE_CLOSE)
-      .value("SPAREN_OPEN", c_token_t::CT_SPAREN_OPEN)
-      .value("SPAREN_CLOSE", c_token_t::CT_SPAREN_CLOSE)
-      .value("FPAREN_OPEN", c_token_t::CT_FPAREN_OPEN)
-      .value("FPAREN_CLOSE", c_token_t::CT_FPAREN_CLOSE)
-      .value("TPAREN_OPEN", c_token_t::CT_TPAREN_OPEN)
-      .value("TPAREN_CLOSE", c_token_t::CT_TPAREN_CLOSE)
-      .value("BRACE_OPEN", c_token_t::CT_BRACE_OPEN)
-      .value("BRACE_CLOSE", c_token_t::CT_BRACE_CLOSE)
-      .value("VBRACE_OPEN", c_token_t::CT_VBRACE_OPEN)
-      .value("VBRACE_CLOSE", c_token_t::CT_VBRACE_CLOSE)
-      .value("SQUARE_OPEN", c_token_t::CT_SQUARE_OPEN)
-      .value("SQUARE_CLOSE", c_token_t::CT_SQUARE_CLOSE)
-      .value("TSQUARE", c_token_t::CT_TSQUARE)
-      .value("MACRO_OPEN", c_token_t::CT_MACRO_OPEN)
-      .value("MACRO_CLOSE", c_token_t::CT_MACRO_CLOSE)
-      .value("MACRO_ELSE", c_token_t::CT_MACRO_ELSE)
-      .value("LABEL", c_token_t::CT_LABEL)
-      .value("LABEL_COLON", c_token_t::CT_LABEL_COLON)
-      .value("FUNCTION", c_token_t::CT_FUNCTION)
-      .value("FUNC_CALL", c_token_t::CT_FUNC_CALL)
-      .value("FUNC_CALL_USER", c_token_t::CT_FUNC_CALL_USER)
-      .value("FUNC_DEF", c_token_t::CT_FUNC_DEF)
-      .value("FUNC_TYPE", c_token_t::CT_FUNC_TYPE)
-      .value("FUNC_VAR", c_token_t::CT_FUNC_VAR)
-      .value("FUNC_PROTO", c_token_t::CT_FUNC_PROTO)
-      .value("FUNC_START", c_token_t::CT_FUNC_START)
-      .value("FUNC_CLASS_DEF", c_token_t::CT_FUNC_CLASS_DEF)
-      .value("FUNC_CLASS_PROTO", c_token_t::CT_FUNC_CLASS_PROTO)
-      .value("FUNC_CTOR_VAR", c_token_t::CT_FUNC_CTOR_VAR)
-      .value("FUNC_WRAP", c_token_t::CT_FUNC_WRAP)
-      .value("PROTO_WRAP", c_token_t::CT_PROTO_WRAP)
-      .value("MACRO_FUNC", c_token_t::CT_MACRO_FUNC)
-      .value("MACRO", c_token_t::CT_MACRO)
-      .value("QUALIFIER", c_token_t::CT_QUALIFIER)
-      .value("EXTERN", c_token_t::CT_EXTERN)
-      .value("DECLSPEC", c_token_t::CT_DECLSPEC)
-      .value("ALIGN", c_token_t::CT_ALIGN)
-      .value("TYPE", c_token_t::CT_TYPE)
-      .value("PTR_TYPE", c_token_t::CT_PTR_TYPE)
-      .value("TYPE_WRAP", c_token_t::CT_TYPE_WRAP)
-      .value("CPP_LAMBDA", c_token_t::CT_CPP_LAMBDA)
-      .value("CPP_LAMBDA_RET", c_token_t::CT_CPP_LAMBDA_RET)
-      .value("TRAILING_RET", c_token_t::CT_TRAILING_RET)
-      .value("BIT_COLON", c_token_t::CT_BIT_COLON)
-      .value("OC_DYNAMIC", c_token_t::CT_OC_DYNAMIC)
-      .value("OC_END", c_token_t::CT_OC_END)
-      .value("OC_IMPL", c_token_t::CT_OC_IMPL)
-      .value("OC_INTF", c_token_t::CT_OC_INTF)
-      .value("OC_PROTOCOL", c_token_t::CT_OC_PROTOCOL)
-      .value("OC_PROTO_LIST", c_token_t::CT_OC_PROTO_LIST)
-      .value("OC_GENERIC_SPEC", c_token_t::CT_OC_GENERIC_SPEC)
-      .value("OC_PROPERTY", c_token_t::CT_OC_PROPERTY)
-      .value("OC_CLASS", c_token_t::CT_OC_CLASS)
-      .value("OC_CLASS_EXT", c_token_t::CT_OC_CLASS_EXT)
-      .value("OC_CATEGORY", c_token_t::CT_OC_CATEGORY)
-      .value("OC_SCOPE", c_token_t::CT_OC_SCOPE)
-      .value("OC_MSG", c_token_t::CT_OC_MSG)
-      .value("OC_MSG_CLASS", c_token_t::CT_OC_MSG_CLASS)
-      .value("OC_MSG_FUNC", c_token_t::CT_OC_MSG_FUNC)
-      .value("OC_MSG_NAME", c_token_t::CT_OC_MSG_NAME)
-      .value("OC_MSG_SPEC", c_token_t::CT_OC_MSG_SPEC)
-      .value("OC_MSG_DECL", c_token_t::CT_OC_MSG_DECL)
-      .value("OC_RTYPE", c_token_t::CT_OC_RTYPE)
-      .value("OC_ATYPE", c_token_t::CT_OC_ATYPE)
-      .value("OC_COLON", c_token_t::CT_OC_COLON)
-      .value("OC_DICT_COLON", c_token_t::CT_OC_DICT_COLON)
-      .value("OC_SEL", c_token_t::CT_OC_SEL)
-      .value("OC_SEL_NAME", c_token_t::CT_OC_SEL_NAME)
-      .value("OC_BLOCK", c_token_t::CT_OC_BLOCK)
-      .value("OC_BLOCK_ARG", c_token_t::CT_OC_BLOCK_ARG)
-      .value("OC_BLOCK_TYPE", c_token_t::CT_OC_BLOCK_TYPE)
-      .value("OC_BLOCK_EXPR", c_token_t::CT_OC_BLOCK_EXPR)
-      .value("OC_BLOCK_CARET", c_token_t::CT_OC_BLOCK_CARET)
-      .value("OC_AT", c_token_t::CT_OC_AT)
-      .value("OC_PROPERTY_ATTR", c_token_t::CT_OC_PROPERTY_ATTR)
-      .value("PP_DEFINE", c_token_t::CT_PP_DEFINE)
-      .value("PP_DEFINED", c_token_t::CT_PP_DEFINED)
-      .value("PP_INCLUDE", c_token_t::CT_PP_INCLUDE)
-      .value("PP_IF", c_token_t::CT_PP_IF)
-      .value("PP_ELSE", c_token_t::CT_PP_ELSE)
-      .value("PP_ENDIF", c_token_t::CT_PP_ENDIF)
-      .value("PP_ASSERT", c_token_t::CT_PP_ASSERT)
-      .value("PP_EMIT", c_token_t::CT_PP_EMIT)
-      .value("PP_ENDINPUT", c_token_t::CT_PP_ENDINPUT)
-      .value("PP_ERROR", c_token_t::CT_PP_ERROR)
-      .value("PP_FILE", c_token_t::CT_PP_FILE)
-      .value("PP_LINE", c_token_t::CT_PP_LINE)
-      .value("PP_SECTION", c_token_t::CT_PP_SECTION)
-      .value("PP_ASM", c_token_t::CT_PP_ASM)
-      .value("PP_UNDEF", c_token_t::CT_PP_UNDEF)
-      .value("PP_PROPERTY", c_token_t::CT_PP_PROPERTY)
-      .value("PP_BODYCHUNK", c_token_t::CT_PP_BODYCHUNK)
-      .value("PP_PRAGMA", c_token_t::CT_PP_PRAGMA)
-      .value("PP_REGION", c_token_t::CT_PP_REGION)
-      .value("PP_ENDREGION", c_token_t::CT_PP_ENDREGION)
-      .value("PP_REGION_INDENT", c_token_t::CT_PP_REGION_INDENT)
-      .value("PP_IF_INDENT", c_token_t::CT_PP_IF_INDENT)
-      .value("PP_IGNORE", c_token_t::CT_PP_IGNORE)
-      .value("PP_OTHER", c_token_t::CT_PP_OTHER)
-      .value("CHAR", c_token_t::CT_CHAR)
-      .value("DEFINED", c_token_t::CT_DEFINED)
-      .value("FORWARD", c_token_t::CT_FORWARD)
-      .value("NATIVE", c_token_t::CT_NATIVE)
-      .value("STATE", c_token_t::CT_STATE)
-      .value("STOCK", c_token_t::CT_STOCK)
-      .value("TAGOF", c_token_t::CT_TAGOF)
-      .value("DOT", c_token_t::CT_DOT)
-      .value("TAG", c_token_t::CT_TAG)
-      .value("TAG_COLON", c_token_t::CT_TAG_COLON)
-      .value("LOCK", c_token_t::CT_LOCK)
-      .value("AS", c_token_t::CT_AS)
-      .value("IN", c_token_t::CT_IN)
-      .value("BRACED", c_token_t::CT_BRACED)
-      .value("THIS", c_token_t::CT_THIS)
-      .value("BASE", c_token_t::CT_BASE)
-      .value("DEFAULT", c_token_t::CT_DEFAULT)
-      .value("GETSET", c_token_t::CT_GETSET)
-      .value("GETSET_EMPTY", c_token_t::CT_GETSET_EMPTY)
-      .value("CONCAT", c_token_t::CT_CONCAT)
-      .value("CS_SQ_STMT", c_token_t::CT_CS_SQ_STMT)
-      .value("CS_SQ_COLON", c_token_t::CT_CS_SQ_COLON)
-      .value("CS_PROPERTY", c_token_t::CT_CS_PROPERTY)
-      .value("SQL_EXEC", c_token_t::CT_SQL_EXEC)
-      .value("SQL_BEGIN", c_token_t::CT_SQL_BEGIN)
-      .value("SQL_END", c_token_t::CT_SQL_END)
-      .value("SQL_WORD", c_token_t::CT_SQL_WORD)
-      .value("SQL_ASSIGN", c_token_t::CT_SQL_ASSIGN)
-      .value("CONSTRUCT", c_token_t::CT_CONSTRUCT)
-      .value("LAMBDA", c_token_t::CT_LAMBDA)
-      .value("ASSERT", c_token_t::CT_ASSERT)
-      .value("ANNOTATION", c_token_t::CT_ANNOTATION)
-      .value("FOR_COLON", c_token_t::CT_FOR_COLON)
-      .value("DOUBLE_BRACE", c_token_t::CT_DOUBLE_BRACE)
-      .value("CNG_HASINC", c_token_t::CT_CNG_HASINC)
-      .value("CNG_HASINCN", c_token_t::CT_CNG_HASINCN)
-      .value("Q_EMIT", c_token_t::CT_Q_EMIT)
-      .value("Q_FOREACH", c_token_t::CT_Q_FOREACH)
-      .value("Q_FOREVER", c_token_t::CT_Q_FOREVER)
-      .value("Q_GADGET", c_token_t::CT_Q_GADGET)
-      .value("Q_OBJECT", c_token_t::CT_Q_OBJECT)
-      .value("MODE", c_token_t::CT_MODE)
-      .value("DI", c_token_t::CT_DI)
-      .value("HI", c_token_t::CT_HI)
-      .value("QI", c_token_t::CT_QI)
-      .value("SI", c_token_t::CT_SI)
-      .value("NOTHROW", c_token_t::CT_NOTHROW)
-      .value("WORD_", c_token_t::CT_WORD_);
+   enum_<E_Token>("TokenType")
+      .value("NONE", E_Token::CT_NONE)
+      .value("EOF", E_Token::CT_EOF)
+      .value("UNKNOWN", E_Token::CT_UNKNOWN)
+      .value("JUNK", E_Token::CT_JUNK)
+      .value("WHITESPACE", E_Token::CT_WHITESPACE)
+      .value("SPACE", E_Token::CT_SPACE)
+      .value("NEWLINE", E_Token::CT_NEWLINE)
+      .value("NL_CONT", E_Token::CT_NL_CONT)
+      .value("COMMENT_CPP", E_Token::CT_COMMENT_CPP)
+      .value("COMMENT", E_Token::CT_COMMENT)
+      .value("COMMENT_MULTI", E_Token::CT_COMMENT_MULTI)
+      .value("COMMENT_EMBED", E_Token::CT_COMMENT_EMBED)
+      .value("COMMENT_START", E_Token::CT_COMMENT_START)
+      .value("COMMENT_END", E_Token::CT_COMMENT_END)
+      .value("COMMENT_WHOLE", E_Token::CT_COMMENT_WHOLE)
+      .value("COMMENT_CPP_ENDIF", E_Token::CT_COMMENT_CPP_ENDIF)
+      .value("COMMENT_ENDIF", E_Token::CT_COMMENT_ENDIF)
+      .value("IGNORED", E_Token::CT_IGNORED)
+      .value("WORD", E_Token::CT_WORD)
+      .value("NUMBER", E_Token::CT_NUMBER)
+      .value("NUMBER_FP", E_Token::CT_NUMBER_FP)
+      .value("STRING", E_Token::CT_STRING)
+      .value("STRING_MULTI", E_Token::CT_STRING_MULTI)
+      .value("IF", E_Token::CT_IF)
+      .value("ELSE", E_Token::CT_ELSE)
+      .value("ELSEIF", E_Token::CT_ELSEIF)
+      .value("FOR", E_Token::CT_FOR)
+      .value("WHILE", E_Token::CT_WHILE)
+      .value("WHILE_OF_DO", E_Token::CT_WHILE_OF_DO)
+      .value("SWITCH", E_Token::CT_SWITCH)
+      .value("CASE", E_Token::CT_CASE)
+      .value("DO", E_Token::CT_DO)
+      .value("SYNCHRONIZED", E_Token::CT_SYNCHRONIZED)
+      .value("VOLATILE", E_Token::CT_VOLATILE)
+      .value("TYPEDEF", E_Token::CT_TYPEDEF)
+      .value("STRUCT", E_Token::CT_STRUCT)
+      .value("ENUM", E_Token::CT_ENUM)
+      .value("ENUM_CLASS", E_Token::CT_ENUM_CLASS)
+      .value("SIZEOF", E_Token::CT_SIZEOF)
+      .value("DECLTYPE", E_Token::CT_DECLTYPE)
+      .value("RETURN", E_Token::CT_RETURN)
+      .value("BREAK", E_Token::CT_BREAK)
+      .value("UNION", E_Token::CT_UNION)
+      .value("GOTO", E_Token::CT_GOTO)
+      .value("CONTINUE", E_Token::CT_CONTINUE)
+      .value("C_CAST", E_Token::CT_C_CAST)
+      .value("CPP_CAST", E_Token::CT_CPP_CAST)
+      .value("D_CAST", E_Token::CT_D_CAST)
+      .value("TYPE_CAST", E_Token::CT_TYPE_CAST)
+      .value("TYPENAME", E_Token::CT_TYPENAME)
+      .value("TEMPLATE", E_Token::CT_TEMPLATE)
+      .value("WHERE_SPEC", E_Token::CT_WHERE_SPEC)
+      .value("ASSIGN", E_Token::CT_ASSIGN)
+      .value("ASSIGN_NL", E_Token::CT_ASSIGN_NL)
+      .value("SASSIGN", E_Token::CT_SASSIGN)
+      .value("ASSIGN_DEFAULT_ARG", E_Token::CT_ASSIGN_DEFAULT_ARG)
+      .value("ASSIGN_FUNC_PROTO", E_Token::CT_ASSIGN_FUNC_PROTO)
+      .value("COMPARE", E_Token::CT_COMPARE)
+      .value("SCOMPARE", E_Token::CT_SCOMPARE)
+      .value("BOOL", E_Token::CT_BOOL)
+      .value("SBOOL", E_Token::CT_SBOOL)
+      .value("ARITH", E_Token::CT_ARITH)
+      .value("SARITH", E_Token::CT_SARITH)
+      .value("CARET", E_Token::CT_CARET)
+      .value("DEREF", E_Token::CT_DEREF)
+      .value("INCDEC_BEFORE", E_Token::CT_INCDEC_BEFORE)
+      .value("INCDEC_AFTER", E_Token::CT_INCDEC_AFTER)
+      .value("MEMBER", E_Token::CT_MEMBER)
+      .value("DC_MEMBER", E_Token::CT_DC_MEMBER)
+      .value("C99_MEMBER", E_Token::CT_C99_MEMBER)
+      .value("INV", E_Token::CT_INV)
+      .value("DESTRUCTOR", E_Token::CT_DESTRUCTOR)
+      .value("NOT", E_Token::CT_NOT)
+      .value("D_TEMPLATE", E_Token::CT_D_TEMPLATE)
+      .value("ADDR", E_Token::CT_ADDR)
+      .value("NEG", E_Token::CT_NEG)
+      .value("POS", E_Token::CT_POS)
+      .value("STAR", E_Token::CT_STAR)
+      .value("PLUS", E_Token::CT_PLUS)
+      .value("MINUS", E_Token::CT_MINUS)
+      .value("AMP", E_Token::CT_AMP)
+      .value("BYREF", E_Token::CT_BYREF)
+      .value("POUND", E_Token::CT_POUND)
+      .value("PREPROC", E_Token::CT_PREPROC)
+      .value("PREPROC_INDENT", E_Token::CT_PREPROC_INDENT)
+      .value("PREPROC_BODY", E_Token::CT_PREPROC_BODY)
+      .value("PP", E_Token::CT_PP)
+      .value("ELLIPSIS", E_Token::CT_ELLIPSIS)
+      .value("RANGE", E_Token::CT_RANGE)
+      .value("NULLCOND", E_Token::CT_NULLCOND)
+      .value("SEMICOLON", E_Token::CT_SEMICOLON)
+      .value("VSEMICOLON", E_Token::CT_VSEMICOLON)
+      .value("COLON", E_Token::CT_COLON)
+      .value("ASM_COLON", E_Token::CT_ASM_COLON)
+      .value("CASE_COLON", E_Token::CT_CASE_COLON)
+      .value("CLASS_COLON", E_Token::CT_CLASS_COLON)
+      .value("CONSTR_COLON", E_Token::CT_CONSTR_COLON)
+      .value("D_ARRAY_COLON", E_Token::CT_D_ARRAY_COLON)
+      .value("COND_COLON", E_Token::CT_COND_COLON)
+      .value("WHERE_COLON", E_Token::CT_WHERE_COLON)
+      .value("QUESTION", E_Token::CT_QUESTION)
+      .value("COMMA", E_Token::CT_COMMA)
+      .value("ASM", E_Token::CT_ASM)
+      .value("ATTRIBUTE", E_Token::CT_ATTRIBUTE)
+      .value("AUTORELEASEPOOL", E_Token::CT_AUTORELEASEPOOL)
+      .value("OC_AVAILABLE", E_Token::CT_OC_AVAILABLE)
+      .value("OC_AVAILABLE_VALUE", E_Token::CT_OC_AVAILABLE_VALUE)
+      .value("CATCH", E_Token::CT_CATCH)
+      .value("WHEN", E_Token::CT_WHEN)
+      .value("WHERE", E_Token::CT_WHERE)
+      .value("CLASS", E_Token::CT_CLASS)
+      .value("DELETE", E_Token::CT_DELETE)
+      .value("EXPORT", E_Token::CT_EXPORT)
+      .value("FRIEND", E_Token::CT_FRIEND)
+      .value("NAMESPACE", E_Token::CT_NAMESPACE)
+      .value("PACKAGE", E_Token::CT_PACKAGE)
+      .value("NEW", E_Token::CT_NEW)
+      .value("OPERATOR", E_Token::CT_OPERATOR)
+      .value("OPERATOR_VAL", E_Token::CT_OPERATOR_VAL)
+      .value("ASSIGN_OPERATOR", E_Token::CT_ASSIGN_OPERATOR)
+      .value("ACCESS", E_Token::CT_ACCESS)
+      .value("ACCESS_COLON", E_Token::CT_ACCESS_COLON)
+      .value("THROW", E_Token::CT_THROW)
+      .value("NOEXCEPT", E_Token::CT_NOEXCEPT)
+      .value("TRY", E_Token::CT_TRY)
+      .value("BRACED_INIT_LIST", E_Token::CT_BRACED_INIT_LIST)
+      .value("USING", E_Token::CT_USING)
+      .value("USING_STMT", E_Token::CT_USING_STMT)
+      .value("USING_ALIAS", E_Token::CT_USING_ALIAS)
+      .value("D_WITH", E_Token::CT_D_WITH)
+      .value("D_MODULE", E_Token::CT_D_MODULE)
+      .value("SUPER", E_Token::CT_SUPER)
+      .value("DELEGATE", E_Token::CT_DELEGATE)
+      .value("BODY", E_Token::CT_BODY)
+      .value("DEBUG", E_Token::CT_DEBUG)
+      .value("DEBUGGER", E_Token::CT_DEBUGGER)
+      .value("INVARIANT", E_Token::CT_INVARIANT)
+      .value("UNITTEST", E_Token::CT_UNITTEST)
+      .value("UNSAFE", E_Token::CT_UNSAFE)
+      .value("FINALLY", E_Token::CT_FINALLY)
+      .value("FIXED", E_Token::CT_FIXED)
+      .value("IMPORT", E_Token::CT_IMPORT)
+      .value("D_SCOPE", E_Token::CT_D_SCOPE)
+      .value("D_SCOPE_IF", E_Token::CT_D_SCOPE_IF)
+      .value("LAZY", E_Token::CT_LAZY)
+      .value("D_MACRO", E_Token::CT_D_MACRO)
+      .value("D_VERSION", E_Token::CT_D_VERSION)
+      .value("D_VERSION_IF", E_Token::CT_D_VERSION_IF)
+      .value("PAREN_OPEN", E_Token::CT_PAREN_OPEN)
+      .value("PAREN_CLOSE", E_Token::CT_PAREN_CLOSE)
+      .value("ANGLE_OPEN", E_Token::CT_ANGLE_OPEN)
+      .value("ANGLE_CLOSE", E_Token::CT_ANGLE_CLOSE)
+      .value("SPAREN_OPEN", E_Token::CT_SPAREN_OPEN)
+      .value("SPAREN_CLOSE", E_Token::CT_SPAREN_CLOSE)
+      .value("FPAREN_OPEN", E_Token::CT_FPAREN_OPEN)
+      .value("FPAREN_CLOSE", E_Token::CT_FPAREN_CLOSE)
+      .value("TPAREN_OPEN", E_Token::CT_TPAREN_OPEN)
+      .value("TPAREN_CLOSE", E_Token::CT_TPAREN_CLOSE)
+      .value("BRACE_OPEN", E_Token::CT_BRACE_OPEN)
+      .value("BRACE_CLOSE", E_Token::CT_BRACE_CLOSE)
+      .value("VBRACE_OPEN", E_Token::CT_VBRACE_OPEN)
+      .value("VBRACE_CLOSE", E_Token::CT_VBRACE_CLOSE)
+      .value("SQUARE_OPEN", E_Token::CT_SQUARE_OPEN)
+      .value("SQUARE_CLOSE", E_Token::CT_SQUARE_CLOSE)
+      .value("TSQUARE", E_Token::CT_TSQUARE)
+      .value("MACRO_OPEN", E_Token::CT_MACRO_OPEN)
+      .value("MACRO_CLOSE", E_Token::CT_MACRO_CLOSE)
+      .value("MACRO_ELSE", E_Token::CT_MACRO_ELSE)
+      .value("LABEL", E_Token::CT_LABEL)
+      .value("LABEL_COLON", E_Token::CT_LABEL_COLON)
+      .value("FUNCTION", E_Token::CT_FUNCTION)
+      .value("FUNC_CALL", E_Token::CT_FUNC_CALL)
+      .value("FUNC_CALL_USER", E_Token::CT_FUNC_CALL_USER)
+      .value("FUNC_DEF", E_Token::CT_FUNC_DEF)
+      .value("FUNC_TYPE", E_Token::CT_FUNC_TYPE)
+      .value("FUNC_VAR", E_Token::CT_FUNC_VAR)
+      .value("FUNC_PROTO", E_Token::CT_FUNC_PROTO)
+      .value("FUNC_START", E_Token::CT_FUNC_START)
+      .value("FUNC_CLASS_DEF", E_Token::CT_FUNC_CLASS_DEF)
+      .value("FUNC_CLASS_PROTO", E_Token::CT_FUNC_CLASS_PROTO)
+      .value("FUNC_CTOR_VAR", E_Token::CT_FUNC_CTOR_VAR)
+      .value("FUNC_WRAP", E_Token::CT_FUNC_WRAP)
+      .value("PROTO_WRAP", E_Token::CT_PROTO_WRAP)
+      .value("MACRO_FUNC", E_Token::CT_MACRO_FUNC)
+      .value("MACRO", E_Token::CT_MACRO)
+      .value("QUALIFIER", E_Token::CT_QUALIFIER)
+      .value("EXTERN", E_Token::CT_EXTERN)
+      .value("DECLSPEC", E_Token::CT_DECLSPEC)
+      .value("ALIGN", E_Token::CT_ALIGN)
+      .value("TYPE", E_Token::CT_TYPE)
+      .value("PTR_TYPE", E_Token::CT_PTR_TYPE)
+      .value("TYPE_WRAP", E_Token::CT_TYPE_WRAP)
+      .value("CPP_LAMBDA", E_Token::CT_CPP_LAMBDA)
+      .value("CPP_LAMBDA_RET", E_Token::CT_CPP_LAMBDA_RET)
+      .value("TRAILING_RET", E_Token::CT_TRAILING_RET)
+      .value("BIT_COLON", E_Token::CT_BIT_COLON)
+      .value("OC_DYNAMIC", E_Token::CT_OC_DYNAMIC)
+      .value("OC_END", E_Token::CT_OC_END)
+      .value("OC_IMPL", E_Token::CT_OC_IMPL)
+      .value("OC_INTF", E_Token::CT_OC_INTF)
+      .value("OC_PROTOCOL", E_Token::CT_OC_PROTOCOL)
+      .value("OC_PROTO_LIST", E_Token::CT_OC_PROTO_LIST)
+      .value("OC_GENERIC_SPEC", E_Token::CT_OC_GENERIC_SPEC)
+      .value("OC_PROPERTY", E_Token::CT_OC_PROPERTY)
+      .value("OC_CLASS", E_Token::CT_OC_CLASS)
+      .value("OC_CLASS_EXT", E_Token::CT_OC_CLASS_EXT)
+      .value("OC_CATEGORY", E_Token::CT_OC_CATEGORY)
+      .value("OC_SCOPE", E_Token::CT_OC_SCOPE)
+      .value("OC_MSG", E_Token::CT_OC_MSG)
+      .value("OC_MSG_CLASS", E_Token::CT_OC_MSG_CLASS)
+      .value("OC_MSG_FUNC", E_Token::CT_OC_MSG_FUNC)
+      .value("OC_MSG_NAME", E_Token::CT_OC_MSG_NAME)
+      .value("OC_MSG_SPEC", E_Token::CT_OC_MSG_SPEC)
+      .value("OC_MSG_DECL", E_Token::CT_OC_MSG_DECL)
+      .value("OC_RTYPE", E_Token::CT_OC_RTYPE)
+      .value("OC_ATYPE", E_Token::CT_OC_ATYPE)
+      .value("OC_COLON", E_Token::CT_OC_COLON)
+      .value("OC_DICT_COLON", E_Token::CT_OC_DICT_COLON)
+      .value("OC_SEL", E_Token::CT_OC_SEL)
+      .value("OC_SEL_NAME", E_Token::CT_OC_SEL_NAME)
+      .value("OC_BLOCK", E_Token::CT_OC_BLOCK)
+      .value("OC_BLOCK_ARG", E_Token::CT_OC_BLOCK_ARG)
+      .value("OC_BLOCK_TYPE", E_Token::CT_OC_BLOCK_TYPE)
+      .value("OC_BLOCK_EXPR", E_Token::CT_OC_BLOCK_EXPR)
+      .value("OC_BLOCK_CARET", E_Token::CT_OC_BLOCK_CARET)
+      .value("OC_AT", E_Token::CT_OC_AT)
+      .value("OC_PROPERTY_ATTR", E_Token::CT_OC_PROPERTY_ATTR)
+      .value("PP_DEFINE", E_Token::CT_PP_DEFINE)
+      .value("PP_DEFINED", E_Token::CT_PP_DEFINED)
+      .value("PP_INCLUDE", E_Token::CT_PP_INCLUDE)
+      .value("PP_IF", E_Token::CT_PP_IF)
+      .value("PP_ELSE", E_Token::CT_PP_ELSE)
+      .value("PP_ENDIF", E_Token::CT_PP_ENDIF)
+      .value("PP_ASSERT", E_Token::CT_PP_ASSERT)
+      .value("PP_EMIT", E_Token::CT_PP_EMIT)
+      .value("PP_ENDINPUT", E_Token::CT_PP_ENDINPUT)
+      .value("PP_ERROR", E_Token::CT_PP_ERROR)
+      .value("PP_FILE", E_Token::CT_PP_FILE)
+      .value("PP_LINE", E_Token::CT_PP_LINE)
+      .value("PP_SECTION", E_Token::CT_PP_SECTION)
+      .value("PP_ASM", E_Token::CT_PP_ASM)
+      .value("PP_UNDEF", E_Token::CT_PP_UNDEF)
+      .value("PP_PROPERTY", E_Token::CT_PP_PROPERTY)
+      .value("PP_BODYCHUNK", E_Token::CT_PP_BODYCHUNK)
+      .value("PP_PRAGMA", E_Token::CT_PP_PRAGMA)
+      .value("PP_REGION", E_Token::CT_PP_REGION)
+      .value("PP_ENDREGION", E_Token::CT_PP_ENDREGION)
+      .value("PP_REGION_INDENT", E_Token::CT_PP_REGION_INDENT)
+      .value("PP_IF_INDENT", E_Token::CT_PP_IF_INDENT)
+      .value("PP_IGNORE", E_Token::CT_PP_IGNORE)
+      .value("PP_OTHER", E_Token::CT_PP_OTHER)
+      .value("CHAR", E_Token::CT_CHAR)
+      .value("DEFINED", E_Token::CT_DEFINED)
+      .value("FORWARD", E_Token::CT_FORWARD)
+      .value("NATIVE", E_Token::CT_NATIVE)
+      .value("STATE", E_Token::CT_STATE)
+      .value("STOCK", E_Token::CT_STOCK)
+      .value("TAGOF", E_Token::CT_TAGOF)
+      .value("DOT", E_Token::CT_DOT)
+      .value("TAG", E_Token::CT_TAG)
+      .value("TAG_COLON", E_Token::CT_TAG_COLON)
+      .value("LOCK", E_Token::CT_LOCK)
+      .value("AS", E_Token::CT_AS)
+      .value("IN", E_Token::CT_IN)
+      .value("BRACED", E_Token::CT_BRACED)
+      .value("THIS", E_Token::CT_THIS)
+      .value("BASE", E_Token::CT_BASE)
+      .value("DEFAULT", E_Token::CT_DEFAULT)
+      .value("GETSET", E_Token::CT_GETSET)
+      .value("GETSET_EMPTY", E_Token::CT_GETSET_EMPTY)
+      .value("CONCAT", E_Token::CT_CONCAT)
+      .value("CS_SQ_STMT", E_Token::CT_CS_SQ_STMT)
+      .value("CS_SQ_COLON", E_Token::CT_CS_SQ_COLON)
+      .value("CS_PROPERTY", E_Token::CT_CS_PROPERTY)
+      .value("SQL_EXEC", E_Token::CT_SQL_EXEC)
+      .value("SQL_BEGIN", E_Token::CT_SQL_BEGIN)
+      .value("SQL_END", E_Token::CT_SQL_END)
+      .value("SQL_WORD", E_Token::CT_SQL_WORD)
+      .value("SQL_ASSIGN", E_Token::CT_SQL_ASSIGN)
+      .value("CONSTRUCT", E_Token::CT_CONSTRUCT)
+      .value("LAMBDA", E_Token::CT_LAMBDA)
+      .value("ASSERT", E_Token::CT_ASSERT)
+      .value("ANNOTATION", E_Token::CT_ANNOTATION)
+      .value("FOR_COLON", E_Token::CT_FOR_COLON)
+      .value("DOUBLE_BRACE", E_Token::CT_DOUBLE_BRACE)
+      .value("CNG_HASINC", E_Token::CT_CNG_HASINC)
+      .value("CNG_HASINCN", E_Token::CT_CNG_HASINCN)
+      .value("Q_EMIT", E_Token::CT_Q_EMIT)
+      .value("Q_FOREACH", E_Token::CT_Q_FOREACH)
+      .value("Q_FOREVER", E_Token::CT_Q_FOREVER)
+      .value("Q_GADGET", E_Token::CT_Q_GADGET)
+      .value("Q_OBJECT", E_Token::CT_Q_OBJECT)
+      .value("MODE", E_Token::CT_MODE)
+      .value("DI", E_Token::CT_DI)
+      .value("HI", E_Token::CT_HI)
+      .value("QI", E_Token::CT_QI)
+      .value("SI", E_Token::CT_SI)
+      .value("NOTHROW", E_Token::CT_NOTHROW)
+      .value("WORD_", E_Token::CT_WORD_);
 
    enum_<lang_flag_e>("Language")
       .value("C", lang_flag_e::LANG_C)
