@@ -10,30 +10,20 @@
 #ifndef UNCRUSTIFY_TYPES_H_INCLUDED
 #define UNCRUSTIFY_TYPES_H_INCLUDED
 
-#include "base_types.h"
-#include "enum_flags.h"
-#include "log_levels.h"
-#include "logger.h"
-#include "option_enum.h"
 #include "options.h"
 #include "pcf_flags.h"
-#include "token_enum.h"    // c_token_t
+#include "token_enum.h"    // E_Token
 #include "unc_text.h"
 #include "uncrustify_limits.h"
 
 #include <assert.h>
-#include <cstdio>
-#include <deque>
-#include <vector>
+#include <cstddef>      // to get size_t
 
 #ifdef HAVE_UTIME_H
 #include <utime.h>
 #endif
 
 
-class ParseFrame;
-
-
 /**
  * abbreviations used:
  *   SS = star style
@@ -46,29 +36,17 @@ class ParseFrame;
 #define UNCRUSTIFY_OFF_TEXT    " *INDENT-OFF*"
 #define UNCRUSTIFY_ON_TEXT     " *INDENT-ON*"
 
-//! returns type (with removed reference) of a variable
-#define noref_decl_t(X)              std::remove_reference<decltype((X))>::type
-
-//! returns type (with removed const and reference) of a variable
-#define nocref_decl_t(X)             std::remove_const<noref_decl_t((X))>::type
-
-//! static casts Y to the type (with removed reference) of X
-#define s_cast_noref_decl_t(X, Y)    static_cast<nocref_decl_t(X)>(Y)
-
-//! performs abs on Y after static casting it to the type (with removed reference) of X
-#define cast_abs(X, Y)               s_cast_noref_decl_t(X, abs(Y))
-
 /**
  * @brief Macro to inform the compiler that a variable is intentionally
  * not in use.
  *
  * @param [in] variableName: The unused variable.
  */
-#define UNUSED(variableName)         ((void)variableName)
+#define UNUSED(variableName)    ((void)variableName)
 
 
 //! Brace stage enum used in brace_cleanup
-enum class brace_stage_e : unsigned int
+enum class E_BraceStage : unsigned int
 {
    NONE,
    PAREN1,      //! expected paren after if/catch (C++)/for/switch/synchronized/while
@@ -94,8 +72,17 @@ enum class char_encoding_e : unsigned int
    e_UTF16_BE   //! utf 16 bit wide, big endian
 };
 
+enum class tracking_type_e : unsigned int
+{
+   TT_NONE,
+   TT_SPACE,
+   TT_NEWLINE,
+   TT_START
+};
 
-struct chunk_t; //forward declaration
+const char *get_tracking_type_e_name(tracking_type_e type);
+
+class Chunk; //forward declaration
 
 
 /**
@@ -103,129 +90,57 @@ struct chunk_t; //forward declaration
  * indent of another chunk. This is needed, as that chunk may be aligned and
  * so the indent cannot be determined in the indent code.
  */
-struct indent_ptr_t
+struct IndentationData
 {
-   chunk_t *ref;
-   int     delta;
+   Chunk *ref;
+   int   delta;
 };
 
 
-struct align_ptr_t
+struct AlignmentData
 {
-   chunk_t *next;       //! nullptr or the chunk that should be under this one
-   bool    right_align; //! AlignStack.m_right_align
-   size_t  star_style;  //! AlignStack.m_star_style
-   size_t  amp_style;   //! AlignStack.m_amp_style
-   int     gap;         //! AlignStack.m_gap
+   Chunk  *next;       //! Chunk::NullChunkPtr or the chunk that should be under this one
+   bool   right_align; //! AlignStack.m_right_align
+   size_t star_style;  //! AlignStack.m_star_style
+   size_t amp_style;   //! AlignStack.m_amp_style
+   int    gap;         //! AlignStack.m_gap
 
    /*
     * col_adj is the amount to alter the column for the token.
     * For example, a dangling '*' would be set to -1.
     * A right-aligned word would be a positive value.
     */
-   int     col_adj;
-   chunk_t *ref;
-   chunk_t *start;
+   int   col_adj;
+   Chunk *ref;
+   Chunk *start;
 };
 
 
-// This is the main type of this program
-struct chunk_t
-{
-   chunk_t()
-   {
-      reset();
-   }
+// for debugging purpose only
+typedef std::pair<size_t, char *>   TrackNumber;   // track for "trackNumber" and "rule"
+typedef std::vector<TrackNumber>    TrackList;     // list of tracks
 
-
-   //! sets all elements of the struct to their default value
-   void reset()
-   {
-      memset(&align, 0, sizeof(align));
-      memset(&indent, 0, sizeof(indent));
-      next          = nullptr;
-      prev          = nullptr;
-      parent        = nullptr;
-      type          = CT_NONE;
-      parent_type   = CT_NONE;
-      orig_line     = 0;
-      orig_col      = 0;
-      orig_col_end  = 0;
-      orig_prev_sp  = 0;
-      flags         = PCF_NONE;
-      column        = 0;
-      column_indent = 0;
-      nl_count      = 0;
-      nl_column     = 0;
-      level         = 0;
-      brace_level   = 0;
-      pp_level      = 0;
-      after_tab     = false;
-      str.clear();
-   }
-
-
-   //! provides the number of characters of string
-   size_t len() const
-   {
-      return(str.size());
-   }
-
-
-   //! provides the content of a string a zero terminated character pointer
-   const char *text() const
-   {
-      return(str.c_str());
-   }
-
-   chunk_t      *next;            //! pointer to next chunk in list
-   chunk_t      *prev;            //! pointer to previous chunk in list
-   chunk_t      *parent;          //! pointer to parent chunk(not always set)
-   align_ptr_t  align;
-   indent_ptr_t indent;
-   c_token_t    type;             //! type of the chunk itself
-   c_token_t    parent_type;      //! type of the parent chunk usually CT_NONE
-                                  //! might be different from parent->parent_type (above)
-   size_t       orig_line;        //! line number of chunk in input file
-   size_t       orig_col;         //! column where chunk started in the input file, is always > 0
-   size_t       orig_col_end;     //! column where chunk ended in the input file, is always > 1
-   UINT32       orig_prev_sp;     //! whitespace before this token
-   pcf_flags_t  flags;            //! see PCF_xxx
-   size_t       column;           //! column of chunk
-   size_t       column_indent;    /** if 1st on a line, set to the 'indent'
-                                   * column, which may be less than the real
-                                   * column used to indent with tabs          */
-   size_t       nl_count;         //! number of newlines in CT_NEWLINE
-   size_t       nl_column;        //! column of the subsequent newline entries(all of them should have the same column)
-   size_t       level;            //! nest level in {, (, or [
-   size_t       brace_level;      //! nest level in braces only
-   size_t       pp_level;         //! nest level in preprocessor
-   bool         after_tab;        //! whether this token was after a tab
-   unc_text     str;              //! the token text
-};
-
-
-//! list of all programming languages Uncrustify supports
-enum lang_flag_e
-{
-   LANG_C    = 0x0001,
-   LANG_CPP  = 0x0002,
-   LANG_D    = 0x0004,
-   LANG_CS   = 0x0008,     //! C# (C-Sharp)
-   LANG_JAVA = 0x0010,
-   LANG_OC   = 0x0020,     //! Objective-C
-   LANG_VALA = 0x0040,
-   LANG_PAWN = 0x0080,
-   LANG_ECMA = 0x0100,     //! ECMA Script (JavaScript)
-
-   LANG_ALLC = 0x017f,     /** LANG_C    | LANG_CPP | LANG_D    | LANG_CS   |
-                            *  LANG_JAVA | LANG_OC  | LANG_VALA | LANG_ECMA   */
-   LANG_ALL  = 0x0fff,     //! applies to all languages
-
-   FLAG_HDR  = 0x2000,     /*<< Header file for C family languages */
-   FLAG_DIG  = 0x4000,     //! digraph/trigraph
-   FLAG_PP   = 0x8000,     //! only appears in a preprocessor
-};
+////! list of all programming languages Uncrustify supports
+//enum lang_flag_e
+//{
+//   LANG_C    = 0x0001,
+//   LANG_CPP  = 0x0002,
+//   LANG_D    = 0x0004,
+//   LANG_CS   = 0x0008,     //! C# (C-Sharp)
+//   LANG_JAVA = 0x0010,
+//   LANG_OC   = 0x0020,     //! Objective-C
+//   LANG_VALA = 0x0040,
+//   LANG_PAWN = 0x0080,
+//   LANG_ECMA = 0x0100,     //! ECMA Script (JavaScript)
+//
+//   LANG_ALLC = 0x017f,     /** LANG_C    | LANG_CPP | LANG_D    | LANG_CS   |
+//                            *  LANG_JAVA | LANG_OC  | LANG_VALA | LANG_ECMA   */
+//   LANG_ALL  = 0x0fff,     //! applies to all languages
+//
+//   FLAG_HDR  = 0x2000,     /*<< Header file for C family languages */
+//   FLAG_DIG  = 0x4000,     //! digraph/trigraph
+//   FLAG_PP   = 0x8000,     //! only appears in a preprocessor
+//};
 
 //! Pattern classes for special keywords
 enum class pattern_class_e : unsigned int
@@ -252,17 +167,18 @@ enum class pattern_class_e : unsigned int
 //! used to link language keywords with some addition information
 struct chunk_tag_t
 {
-   const char *tag;        //! name of the keyword e.g. "bool"
-   c_token_t  type;        //! uncrustify type assigned to that keyword
-   size_t     lang_flags;  //! programming language that uses this keyword
+   const char *tag;       //! name of the keyword e.g. "bool"
+   E_Token    type;       //! uncrustify type assigned to that keyword
+   size_t     lang_flags; //! programming language that uses this keyword
 };
 
 
 struct align_t
 {
-   size_t    col;
-   c_token_t type;
-   size_t    len;    //! length of the token + space
+   size_t  col;
+   E_Token type;
+   size_t  len;      //! length of the token + space
+   Chunk   *ref;     // Issue #3786
 };
 
 //! holds information and data of a file
@@ -300,7 +216,6 @@ struct cp_data_t
    int               check_fail_cnt;       //! total failure count
    bool              if_changed;
 
-   UINT32            error_count;       //! counts how many errors occurred so far
    std::string       filename;
 
    file_mem          file_hdr;          // for cmt_insert_file_header
@@ -308,6 +223,7 @@ struct cp_data_t
    file_mem          func_hdr;          // for cmt_insert_func_header
    file_mem          oc_msg_hdr;        // for cmt_insert_oc_msg_header
    file_mem          class_hdr;         // for cmt_insert_class_header
+   file_mem          reflow_fold_regex; // for cmt_reflow_fold_regex_file
 
    size_t            lang_flags;        //! defines the language of the source input
    bool              lang_forced;       //! overwrites automatic language detection
@@ -325,10 +241,10 @@ struct cp_data_t
 
    // stuff to auto-detect line endings
    UINT32            le_counts[uncrustify::line_end_styles];
-   unc_text          newline;
+   UncText           newline;
 
-   int               did_newline;       //! flag indicates if a newline was added or converted
-   c_token_t         in_preproc;
+   bool              did_newline;       //! flag indicates if a newline was added or converted
+   E_Token           in_preproc;
    int               preproc_ncnl_count;
    bool              output_trailspace;
    bool              output_tab_as_space;
@@ -350,11 +266,14 @@ struct cp_data_t
 
    const char        *phase_name;
    const char        *dumped_file;
+   // for debugging purpose only
+   tracking_type_e   html_type  = tracking_type_e::TT_NONE;
+   const char        *html_file = nullptr;
 };
 
 extern cp_data_t cpd;  // TODO: can we avoid this external variable?
 
-const char *get_brace_stage_name(brace_stage_e brace_stage);
+const char *get_brace_stage_name(E_BraceStage brace_stage);
 
 const char *get_unc_stage_name(unc_stage_e unc_stage);
 
