@@ -8,14 +8,6 @@
 
 #include "unicode.h"
 
-#include "prototypes.h"
-#include "unc_ctype.h"
-#include "uncrustify.h"
-#include "uncrustify_types.h"
-
-#include <cstdlib>
-#include <cstring>
-
 
 using namespace std;
 
@@ -218,7 +210,8 @@ static bool decode_utf8(const vector<UINT8> &in_data, deque<int> &out_data)
          return(false);
       }
 
-      while (cnt-- > 0 && idx < in_data.size())
+      while (  cnt-- > 0
+            && idx < in_data.size())
       {
          int tmp = in_data[idx++];
 
@@ -279,11 +272,13 @@ static bool decode_utf16(const vector<UINT8> &in_data, deque<int> &out_data, cha
    }
    size_t idx = 2;
 
-   if ((in_data[0] == 0xfe) && (in_data[1] == 0xff))
+   if (  (in_data[0] == 0xfe)
+      && (in_data[1] == 0xff))
    {
       enc = char_encoding_e::e_UTF16_BE;
    }
-   else if ((in_data[0] == 0xff) && (in_data[1] == 0xfe))
+   else if (  (in_data[0] == 0xff)
+           && (in_data[1] == 0xfe))
    {
       enc = char_encoding_e::e_UTF16_LE;
    }
@@ -337,7 +332,8 @@ static bool decode_utf16(const vector<UINT8> &in_data, deque<int> &out_data, cha
          ch += 0x10000;
          out_data.push_back(ch);
       }
-      else if (  (ch >= 0 && ch < 0xD800)
+      else if (  (  ch >= 0
+                 && ch < 0xD800)
               || ch >= 0xE000)
       {
          out_data.push_back(ch);
@@ -358,13 +354,15 @@ static bool decode_bom(const vector<UINT8> &in_data, char_encoding_e &enc)
 
    if (in_data.size() >= 2)
    {
-      if ((in_data[0] == 0xfe) && (in_data[1] == 0xff))
+      if (  (in_data[0] == 0xfe)
+         && (in_data[1] == 0xff))
       {
          enc = char_encoding_e::e_UTF16_BE;
          return(true);
       }
 
-      if ((in_data[0] == 0xff) && (in_data[1] == 0xfe))
+      if (  (in_data[0] == 0xff)
+         && (in_data[1] == 0xfe))
       {
          enc = char_encoding_e::e_UTF16_LE;
          return(true);
@@ -469,8 +467,10 @@ static void write_utf8(int ch)
 static void write_utf16(int ch, bool be)
 {
    // U+0000 to U+D7FF and U+E000 to U+FFFF
-   if (  (ch >= 0 && ch < 0xD800)
-      || (ch >= 0xE000 && ch < 0x10000))
+   if (  (  ch >= 0
+         && ch < 0xD800)
+      || (  ch >= 0xE000
+         && ch < 0x10000))
    {
       if (be)
       {
@@ -483,7 +483,8 @@ static void write_utf16(int ch, bool be)
          write_byte(ch >> 8);
       }
    }
-   else if (ch >= 0x10000 && ch < 0x110000)
+   else if (  ch >= 0x10000
+           && ch < 0x110000)
    {
       int v1 = ch - 0x10000;
       int w1 = 0xD800 + (v1 >> 10);
@@ -511,7 +512,7 @@ static void write_utf16(int ch, bool be)
 } // write_utf16
 
 
-void write_bom(void)
+void write_bom()
 {
    switch (cpd.enc)
    {
@@ -570,7 +571,7 @@ void write_char(int ch)
 }
 
 
-void write_string(const unc_text &text)
+void write_string(const UncText &text)
 {
    for (size_t idx = 0; idx < text.size(); idx++)
    {
