@@ -1,6 +1,6 @@
 /**
  * @file unicode.h
- * prototypes for unicode.c
+ * prototypes for unicode.cpp
  *
  * @author  Ben Gardner
  * @license GPL v2+
@@ -9,11 +9,10 @@
 #ifndef UNICODE_H_INCLUDED
 #define UNICODE_H_INCLUDED
 
-#include "unc_text.h"
 #include "uncrustify_types.h"
 
 
-void write_bom(void);
+void write_bom();
 
 
 /**
@@ -22,7 +21,7 @@ void write_bom(void);
 void write_char(int ch);
 
 
-void write_string(const unc_text &text);
+void write_string(const UncText &text);
 
 
 //! Figure out the encoding and convert to an int sequence
