@@ -1,6 +1,6 @@
 /**
  * @file width.h
- * prototypes for width.c
+ * prototypes for width.cpp
  *
  * @author  Ben Gardner
  * @license GPL v2+
@@ -15,7 +15,7 @@
  * Step forward until a token goes beyond the limit and then call split_line()
  * to split the line at or before that point.
  */
-void do_code_width(void);
+void do_code_width();
 
 
 #endif /* WIDTH_H_INCLUDED */
