@@ -32,7 +32,8 @@ void ble( int a, char b )
 
 }
 
-void ble2( int a, char b )
+void ble2( int  a,
+           char b )
 {
 
 
