@@ -33,7 +33,7 @@ void f2()
 
 void f3a()
 {
-   auto a = []  {};
+   auto a = [] {};
    auto b = [] { return(true); };
 }
 
@@ -70,3 +70,25 @@ void g2()
    Invoke(a, b,
           [&one, two] (int *a, Something&b) { std::cout << "blah: " << *a; });
 }
+
+void h1()
+{
+   [] () -> int {
+      return(33);
+   }();
+
+   [] () noexcept ->int {
+      return(33);
+   }();
+}
+
+void h2()
+{
+   [] (int a) -> int {
+      return(a + 33);
+   }(21);
+
+   [] (int a) noexcept ->int {
+      return(a + 33);
+   }(21);
+}
