@@ -37,7 +37,7 @@ void f2()
 
 void f3a()
 {
-	auto a = []  {
+	auto a = [] {
 		 };
 	auto b = [] {
 			 return true;
@@ -60,14 +60,14 @@ void f3c()
 
 void g1()
 {
-	auto a = [ = ] (int* a, Something &b)  {
+	auto a = [=] (int* a, Something &b) {
 			 std::cout << "blah: " << *a;
 		 };
 }
 
 void g1a()
 {
-	std::for_each(a, b, [] (Something& b){
+	std::for_each(a, b, [] (Something& b) {
 		std::cout<<"blah: "<<*a;
 	});
 }
@@ -82,7 +82,33 @@ void g1b()
 void g2()
 {
 	Invoke(a, b,
-	       [&one, two] (int *a, Something&b){
+	       [&one, two] (int *a, Something&b) {
 		std::cout << "blah: " << *a;
 	});
 }
+
+void h1()
+{
+	[] () -> int
+	{
+		return 33;
+	}();
+
+	[] () noexcept ->int
+	{
+		return 33;
+	}();
+}
+
+void h2()
+{
+	[] (int a) -> int
+	{
+		return a + 33;
+	}(21);
+
+	[] (int a) noexcept ->int
+	{
+		return a + 33;
+	}(21);
+}
