@@ -60,7 +60,7 @@ void f3c()
 
 void g1()
 {
-	auto a = [ = ](int* a, Something &b)  {
+	auto a = [=](int* a, Something &b){
 			 std::cout << "blah: " << *a;
 		 };
 }
@@ -74,7 +74,7 @@ void g1a()
 
 void g1b()
 {
-	std::for_each(a, b, []  (int& b)->foo {
+	std::for_each(a, b, [](int& b)->foo {
 		b+=3; return(b);
 	});
 }
@@ -82,7 +82,33 @@ void g1b()
 void g2()
 {
 	Invoke(a, b,
-	       [&one, two]  (int *a, Something&b){
+	       [&one, two](int *a, Something&b){
 		std::cout << "blah: " << *a;
 	});
 }
+
+void h1()
+{
+	[]() -> int
+	{
+		return 33;
+	}();
+
+	[]() noexcept ->int
+	{
+		return 33;
+	}();
+}
+
+void h2()
+{
+	[](int a) -> int
+	{
+		return a + 33;
+	}(21);
+
+	[](int a) noexcept ->int
+	{
+		return a + 33;
+	}(21);
+}
