@@ -69,6 +69,10 @@ class I
 {
 };
 
+using namespace F;
+
+namespace M
+{
 void bar4();
 
 /* multiline test comment
@@ -77,11 +81,9 @@ template<typename ... Args>
 // test comment between template specification and associated class
 class H
 {
-
     // nested class
     template<typename ...>
     friend class I;
-
     friend class J;
 
     // nested class K
@@ -95,3 +97,22 @@ class H
     };
 
 };
+
+}
+
+class AA;
+class AB;
+
+namespace BA
+{
+class BB;
+class BC;
+
+class BD
+{
+public:
+    friend class BE;
+    BD();
+};
+
+}
