@@ -1,4 +1,4 @@
-class SomeClass ()
+class SomeClass
 {
 public:
 void SomeFunction
@@ -9,4 +9,4 @@ void SomeFunction
 {
     DoSomeStuff();
 }
-}
\ No newline at end of file
+}
