@@ -1,7 +1,7 @@
 void f1()
 {
     auto a =
-    [=](int *a, Something & b)
+    [=]   (int *a, Something & b)
     {
         std::cout << "blah: " << *a;
     };
@@ -37,7 +37,7 @@ void f2()
 
 void f3a()
 {
-   auto a = []  {};
+   auto a = []    {};
    auto b = []{return true;};
 }
 
@@ -57,7 +57,7 @@ void f3c()
 
 void g1()
 {
-   auto a = [ = ](int* a, Something &b)  { std::cout << "blah: " << *a; };
+   auto a = [   =     ](int* a, Something &b)    { std::cout << "blah: " << *a; };
 }
 
 void g1a()
@@ -75,3 +75,29 @@ void g2()
    Invoke(a, b,
           [&one, two]  (int *a, Something&b){ std::cout << "blah: " << *a; });
 }
+
+void h1()
+{
+   []() -> int
+   {
+      return 33;
+   }();
+
+   []() noexcept -> int
+   {
+      return 33;
+   }();
+}
+
+void h2()
+{
+   [](int a) -> int
+   {
+      return a + 33;
+   }(21);
+
+   [](int a) noexcept -> int
+   {
+      return a + 33;
+   }(21);
+}
