@@ -54,7 +54,9 @@ void foo4();
 class I
 {
 };
-
+using namespace F;
+namespace M
+{
 void bar4();
 /* multiline test comment
    before class */
@@ -74,3 +76,20 @@ class K
 class L { };
 };
 };
+}
+
+class AA;
+class AB;
+
+namespace BA
+{
+class BB;
+class BC;
+
+class BD
+{
+public:
+  friend class BE;
+  BD();
+};
+}
